/** @file sys_startup.c 
*   @brief Startup Source File
*   @date 15.Aug.2012
*   @version 03.02.00
*
*   This file contains:
*   - Include Files
*   - Type Definitions
*   - External Functions
*   - VIM RAM Setup
*   - Startup Routine
*   .
*   which are relevant for the Startup.
*/

/* (c) Texas Instruments 2009-2012, All rights reserved. */

@@USERCODE


/* Include Files */

#include "%%HDRCOMMON%%"
#include "%%HDRSYSTEM%%"
#include "%%HDRVIM%%"
#include "%%HDRCORE%%"
#include "sys_selftest.h"
#include "esm.h"
#include "mibspi.h"

@@USERCODE


/* Type Definitions */
#if %%TOOLS:TI%%

typedef void (*handler_fptr)(const uint8_t *in, uint8_t *out);
#endif

@@USERCODE


/* External Functions */
#if %%TOOLS:TI%%

#pragma WEAK(__TI_Handler_Table_Base)
#pragma WEAK(__TI_Handler_Table_Limit)
#pragma WEAK(__TI_CINIT_Base)
#pragma WEAK(__TI_CINIT_Limit)

extern uint32_t   __TI_Handler_Table_Base;
extern uint32_t   __TI_Handler_Table_Limit;
extern uint32_t   __TI_CINIT_Base;
extern uint32_t   __TI_CINIT_Limit;
extern uint32_t   __TI_PINIT_Base;
extern uint32_t   __TI_PINIT_Limit;
extern uint32_t * __binit__;

extern void main(void);
extern void exit(void);
#endif
#if %%TOOLS:ARM%%

extern void __main(void);
#endif
#if %%TOOLS:IAR%%

extern void __cmain(void);
#endif

extern void muxInit(void);
#if %%SYSTEM:SAFETY_INIT_STC_CPUSELFTEST_ENA%%
void afterSTC(void);
#endif

@@USERCODE


#if %%VIM_CONFIG_NEW%%
/* Vim Ram Definition */
/** @struct vimRam
*   @brief Vim Ram Definition
*
*   This type is used to access the Vim Ram.
*/
/** @typedef vimRAM_t
*   @brief Vim Ram Type Definition
*
*   This type is used to access the Vim Ram.
*/
typedef volatile struct vimRam
{
    t_isrFuncPTR ISR[VIM_CHANNELS + 1];
} vimRAM_t;

#define vimRAM ((vimRAM_t *)0xFFF82000U)

static const t_isrFuncPTR s_vim_init[] =
{
    &%%VIM_PHANTOM_NAME%%,
    &%%VIM_CHANNEL_0_NAME%%,
    &%%VIM_CHANNEL_1_NAME%%,
#if %%SYSTEM:VIM_CHANNEL_2_INT_ENABLE%%
    &%%VIM_CHANNEL_2_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_3_INT_ENABLE%%
    &%%VIM_CHANNEL_3_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_4_INT_ENABLE%%
    &%%VIM_CHANNEL_4_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_5_INT_ENABLE%%
    &%%VIM_CHANNEL_5_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_6_INT_ENABLE%%
    &%%VIM_CHANNEL_6_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_7_INT_ENABLE%%
    &%%VIM_CHANNEL_7_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_8_INT_ENABLE%%
    &%%VIM_CHANNEL_8_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_9_INT_ENABLE%%
    &%%VIM_CHANNEL_9_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_10_INT_ENABLE%%
    &%%VIM_CHANNEL_10_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_11_INT_ENABLE%%
    &%%VIM_CHANNEL_11_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_12_INT_ENABLE%%
    &%%VIM_CHANNEL_12_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_13_INT_ENABLE%%
    &%%VIM_CHANNEL_13_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_14_INT_ENABLE%%
    &%%VIM_CHANNEL_14_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_15_INT_ENABLE%%
    &%%VIM_CHANNEL_15_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_16_INT_ENABLE%%
    &%%VIM_CHANNEL_16_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_17_INT_ENABLE%%
    &%%VIM_CHANNEL_17_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_18_INT_ENABLE%%
    &%%VIM_CHANNEL_18_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_19_INT_ENABLE%%
    &%%VIM_CHANNEL_19_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_20_INT_ENABLE%%
    &%%VIM_CHANNEL_20_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_21_INT_ENABLE%%
    &%%VIM_CHANNEL_21_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_22_INT_ENABLE%%
    &%%VIM_CHANNEL_22_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_23_INT_ENABLE%%
    &%%VIM_CHANNEL_23_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_24_INT_ENABLE%%
    &%%VIM_CHANNEL_24_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_25_INT_ENABLE%%
    &%%VIM_CHANNEL_25_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_26_INT_ENABLE%%
    &%%VIM_CHANNEL_26_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_27_INT_ENABLE%%
    &%%VIM_CHANNEL_27_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_28_INT_ENABLE%%
    &%%VIM_CHANNEL_28_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_29_INT_ENABLE%%
    &%%VIM_CHANNEL_29_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_30_INT_ENABLE%%
    &%%VIM_CHANNEL_30_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_31_INT_ENABLE%%
    &%%VIM_CHANNEL_31_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_32_INT_ENABLE%%
    &%%VIM_CHANNEL_32_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_33_INT_ENABLE%%
    &%%VIM_CHANNEL_33_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_34_INT_ENABLE%%
    &%%VIM_CHANNEL_34_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_35_INT_ENABLE%%
    &%%VIM_CHANNEL_35_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_36_INT_ENABLE%%
    &%%VIM_CHANNEL_36_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_37_INT_ENABLE%%
    &%%VIM_CHANNEL_37_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_38_INT_ENABLE%%
    &%%VIM_CHANNEL_38_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_39_INT_ENABLE%%
    &%%VIM_CHANNEL_39_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_40_INT_ENABLE%%
    &%%VIM_CHANNEL_40_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_41_INT_ENABLE%%
    &%%VIM_CHANNEL_41_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_42_INT_ENABLE%%
    &%%VIM_CHANNEL_42_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_43_INT_ENABLE%%
    &%%VIM_CHANNEL_43_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_44_INT_ENABLE%%
    &%%VIM_CHANNEL_44_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_45_INT_ENABLE%%
    &%%VIM_CHANNEL_45_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_46_INT_ENABLE%%
    &%%VIM_CHANNEL_46_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_47_INT_ENABLE%%
    &%%VIM_CHANNEL_47_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_48_INT_ENABLE%%
    &%%VIM_CHANNEL_48_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_49_INT_ENABLE%%
    &%%VIM_CHANNEL_49_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_50_INT_ENABLE%%
    &%%VIM_CHANNEL_50_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_51_INT_ENABLE%%
    &%%VIM_CHANNEL_51_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_52_INT_ENABLE%%
    &%%VIM_CHANNEL_52_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_53_INT_ENABLE%%
    &%%VIM_CHANNEL_53_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_54_INT_ENABLE%%
    &%%VIM_CHANNEL_54_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_55_INT_ENABLE%%
    &%%VIM_CHANNEL_55_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_56_INT_ENABLE%%
    &%%VIM_CHANNEL_56_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_57_INT_ENABLE%%
    &%%VIM_CHANNEL_57_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_58_INT_ENABLE%%
    &%%VIM_CHANNEL_58_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_59_INT_ENABLE%%
    &%%VIM_CHANNEL_59_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_60_INT_ENABLE%%
    &%%VIM_CHANNEL_60_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_61_INT_ENABLE%%
    &%%VIM_CHANNEL_61_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_62_INT_ENABLE%%
    &%%VIM_CHANNEL_62_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_63_INT_ENABLE%%
    &%%VIM_CHANNEL_63_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_64_INT_ENABLE%%
    &%%VIM_CHANNEL_64_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_65_INT_ENABLE%%
    &%%VIM_CHANNEL_65_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_66_INT_ENABLE%%
    &%%VIM_CHANNEL_66_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_67_INT_ENABLE%%
    &%%VIM_CHANNEL_67_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_68_INT_ENABLE%%
    &%%VIM_CHANNEL_68_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_69_INT_ENABLE%%
    &%%VIM_CHANNEL_69_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_70_INT_ENABLE%%
    &%%VIM_CHANNEL_70_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_71_INT_ENABLE%%
    &%%VIM_CHANNEL_71_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_72_INT_ENABLE%%
    &%%VIM_CHANNEL_72_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_73_INT_ENABLE%%
    &%%VIM_CHANNEL_73_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_74_INT_ENABLE%%
    &%%VIM_CHANNEL_74_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_75_INT_ENABLE%%
    &%%VIM_CHANNEL_75_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_76_INT_ENABLE%%
    &%%VIM_CHANNEL_76_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_77_INT_ENABLE%%
    &%%VIM_CHANNEL_77_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_78_INT_ENABLE%%
    &%%VIM_CHANNEL_78_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_79_INT_ENABLE%%
    &%%VIM_CHANNEL_79_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_80_INT_ENABLE%%
    &%%VIM_CHANNEL_80_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_81_INT_ENABLE%%
    &%%VIM_CHANNEL_81_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_82_INT_ENABLE%%
    &%%VIM_CHANNEL_82_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_83_INT_ENABLE%%
    &%%VIM_CHANNEL_83_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_84_INT_ENABLE%%
    &%%VIM_CHANNEL_84_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_85_INT_ENABLE%%
    &%%VIM_CHANNEL_85_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_86_INT_ENABLE%%
    &%%VIM_CHANNEL_86_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_87_INT_ENABLE%%
    &%%VIM_CHANNEL_87_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_88_INT_ENABLE%%
    &%%VIM_CHANNEL_88_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_89_INT_ENABLE%%
    &%%VIM_CHANNEL_89_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_90_INT_ENABLE%%
    &%%VIM_CHANNEL_90_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_91_INT_ENABLE%%
    &%%VIM_CHANNEL_91_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_92_INT_ENABLE%%
    &%%VIM_CHANNEL_92_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_93_INT_ENABLE%%
    &%%VIM_CHANNEL_93_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_94_INT_ENABLE%%
    &%%VIM_CHANNEL_94_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_95_INT_ENABLE%%
    &%%VIM_CHANNEL_95_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_96_INT_ENABLE%%
    &%%VIM_CHANNEL_96_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_97_INT_ENABLE%%
    &%%VIM_CHANNEL_97_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_98_INT_ENABLE%%
    &%%VIM_CHANNEL_98_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_99_INT_ENABLE%%
    &%%VIM_CHANNEL_99_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_100_INT_ENABLE%%
    &%%VIM_CHANNEL_100_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_101_INT_ENABLE%%
    &%%VIM_CHANNEL_101_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_102_INT_ENABLE%%
    &%%VIM_CHANNEL_102_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_103_INT_ENABLE%%
    &%%VIM_CHANNEL_103_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_104_INT_ENABLE%%
    &%%VIM_CHANNEL_104_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_105_INT_ENABLE%%
    &%%VIM_CHANNEL_105_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_106_INT_ENABLE%%
    &%%VIM_CHANNEL_106_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_107_INT_ENABLE%%
    &%%VIM_CHANNEL_107_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_108_INT_ENABLE%%
    &%%VIM_CHANNEL_108_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_109_INT_ENABLE%%
    &%%VIM_CHANNEL_109_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_110_INT_ENABLE%%
    &%%VIM_CHANNEL_110_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_111_INT_ENABLE%%
    &%%VIM_CHANNEL_111_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_112_INT_ENABLE%%
    &%%VIM_CHANNEL_112_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_113_INT_ENABLE%%
    &%%VIM_CHANNEL_113_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_114_INT_ENABLE%%
    &%%VIM_CHANNEL_114_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_115_INT_ENABLE%%
    &%%VIM_CHANNEL_115_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_116_INT_ENABLE%%
    &%%VIM_CHANNEL_116_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_117_INT_ENABLE%%
    &%%VIM_CHANNEL_117_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_118_INT_ENABLE%%
    &%%VIM_CHANNEL_118_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_119_INT_ENABLE%%
    &%%VIM_CHANNEL_119_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_120_INT_ENABLE%%
    &%%VIM_CHANNEL_120_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_121_INT_ENABLE%%
    &%%VIM_CHANNEL_121_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_122_INT_ENABLE%%
    &%%VIM_CHANNEL_122_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_123_INT_ENABLE%%
    &%%VIM_CHANNEL_123_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_124_INT_ENABLE%%
    &%%VIM_CHANNEL_124_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_125_INT_ENABLE%%
    &%%VIM_CHANNEL_125_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_126_INT_ENABLE%%
    &%%VIM_CHANNEL_126_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
#if %%SYSTEM:VIM_CHANNEL_127_INT_ENABLE%%
    &%%VIM_CHANNEL_127_NAME%%,
#else
    &%%VIM_PHANTOM_NAME%%,
#endif
};
#endif


/* Startup Routine */

@@USERCODE

#if %%TOOLS:TI%%
#pragma CODE_STATE(%%CORE_HANDLER_TABLE_RESET_ENTRY%%, 32)
#pragma INTERRUPT(%%CORE_HANDLER_TABLE_RESET_ENTRY%%, RESET)
#endif
#if %%TOOLS:ARM%%
__declspec(noreturn)
__attribute__ ((section ("reset"))) 
#endif
#if %%TOOLS:IAR%%
/* Note: stackless keyword is supported since compiler version 6.20.1 */
__stackless
#endif

void %%CORE_HANDLER_TABLE_RESET_ENTRY%%()
{
	
@@USERCODE

    /* Initialize Core Registers to avoid CCM Error */
    _coreInitRegisters_();

@@USERCODE

    /* Initialize Stack Pointers */
    _coreInitStackPointer_();

@@USERCODE

#if %%SYSTEM:ERRATA_WORKAROUND_1%%	
	/* Work Around for Errata DEVICE#140: ( Only on Rev A silicon) 
	 *
	 * Errata Description:
	 *            The Core Compare Module(CCM-R4) may cause nERROR to be asserted after a cold power-on
	 * Workaround:
	 *            Clear ESM Group2 Channel 2 error in ESMSR2 and Compare error in CCMSR register */
    if (DEVICE_ID_REV == 0x802AAD05)
    {
        _esmCcmErrorsClear_();
    }
	
@@USERCODE
#endif

    /* Enable CPU Event Export */
    /* This allows the CPU to signal any single-bit or double-bit errors detected
     * by its ECC logic for accesses to program flash or data RAM.
     */
	_coreEnableEventBusExport_();

#if %%SYSTEM:FLASH_ECC_ENABLE%%	
@@USERCODE	

    /* Enable response to ECC errors indicated by CPU for accesses to flash */
    flashWREG->FEDACCTRL1 = 0x000A060A;

@@USERCODE

    /* Enable CPU ECC checking for ATCM (flash accesses) */
	_coreEnableFlashEcc_();
#endif

@@USERCODE

    /* Reset handler: the following instructions read from the system exception status register
     * to identify the cause of the CPU reset.
     */

	/* check for power-on reset condition */
	if ((SYS_EXCEPTION & POWERON_RESET) != 0)
	{
@@USERCODE
	    
		/* clear all reset status flags */
		SYS_EXCEPTION = 0xFFFF;

@@USERCODE

#if %%SYSTEM:ERRATA_WORKAROUND_2%%	
/* Work Around for Errata CORTEX-R4#66:
 * 
 * Errata Description:            
 *            Register Corruption During A Load-Multiple Instruction At An Exception Vector
 * Workaround:
 *            Disable out-of-order completion for divide instructions in Auxiliary Control register */
        asm(" push {r0}");
        asm(" mrc p15, #0, r0, c1, c0, #1"); /* Read Auxiliary Control register */
  	    asm(" orr r0, r0, #0x80");           /* Set BIT 7 (Disable out-of-order completion for divide instructions.) */
   	    asm(" mcr p15, #0, r0, c1, c0, #1"); /* Write Auxiliary Control register */
        asm(" pop {r0}");
	
@@USERCODE

#endif
#if %%SYSTEM:ERRATA_WORKAROUND_3%%	
/* Work Around for Errata CORTEX-R4#57:
 * 
 * Errata Description: 
 *            Conditional VMRS APSR_Nzcv, FPSCR May Evaluate With Incorrect Flags
 * Workaround:
 *            Disable out-of-order single-precision floating point multiply-accumulate instruction completion */
        asm(" push {r0}");
	    asm(" mrc p15, #0, r0, c15, c0, #0"); /* Read Secondary Auxiliary Control Register */
        asm(" orr r0, r0, #0x10000");         /* Set BIT 16 (Set DOOFMACS) */
        asm(" mcr p15, #0, r0, c15, c0, #0"); /* Write Secondary Auxiliary Control Register */    	
        asm(" pop {r0}");
	
@@USERCODE

#endif
		/* continue with normal start-up sequence */
	}
	else if ((SYS_EXCEPTION & OSC_FAILURE_RESET) != 0)
	{
		/* Reset caused due to oscillator failure.
		Add user code here to handle oscillator failure */

@@USERCODE
	}
	else if ((SYS_EXCEPTION & WATCHDOG_RESET) !=0 )
	{
		/* Reset caused due 
		 *  1) windowed watchdog violation - Add user code here to handle watchdog violation.
		 *  2) ICEPICK Reset - After loading code via CCS / System Reset through CCS
		 */
		/* Check the WatchDog Status register */
	    if(WATCHDOG_STATUS != 0U)
		{
		    /* Add user code here to handle watchdog violation. */ 
@@USERCODE

		    /* Clear the Watchdog reset flag in Exception Status register */ 
		    SYS_EXCEPTION = WATCHDOG_RESET;
		
@@USERCODE
		}
		else
		{
		    /* Clear the ICEPICK reset flag in Exception Status register */ 
		    SYS_EXCEPTION = ICEPICK_RESET;
@@USERCODE		
		}
	}
	else if ((SYS_EXCEPTION & CPU_RESET) !=0 )
	{
		/* Reset caused due to CPU reset.
		CPU reset can be caused by CPU self-test completion, or
		by toggling the "CPU RESET" bit of the CPU Reset Control Register. */

@@USERCODE

		/* clear all reset status flags */
		SYS_EXCEPTION = CPU_RESET;

#if %%SYSTEM:SAFETY_INIT_STC_CPUSELFTEST_ENA%%	
		/* reset could be caused by stcSelfCheck run or by an actual CPU self-test run */
		
		/* check if this was an stcSelfCheck run */
		if ((stcREG->STCSCSCR & 0xF) == 0xA)			
		{
			/* check if the self-test fail bit is set */
			if ((stcREG->STCGSTAT & 0x3) != 0x3)
			{
				/* STC self-check has failed */
				stcSelfCheckFail();						
			}
			/* STC self-check has passed */
			else										
			{
				/* clear self-check mode */
				stcREG->STCSCSCR = 0x05;				
				
				/* clear STC global status flags */
				stcREG->STCGSTAT = 0x3;				
				
				/* clear ESM group1 channel 27 status flag */
				esmREG->ESTATUS1[0] = 0x08000000;		
				
				/* Start CPU Self-Test */
				cpuSelfTest(STC_INTERVAL, STC_MAX_TIMEOUT, TRUE);							
			}
		}
		/* CPU reset caused by CPU self-test completion */
		else if ((stcREG->STCGSTAT & 0x1) == 0x1)		
		{
		    /* Self-Test Fail flag is set */
			if ((stcREG->STCGSTAT & 0x2) == 0x2)		
			{
				/* Call CPU self-test failure handler */
				cpuSelfTestFail();					
			}
			/* CPU self-test completed successfully */
			else										
			{
			    /* Continue start-up sequence after CPU STC completed */
				afterSTC();								
			}
		}
		/* CPU reset caused by software writing to CPU RESET bit */
		else											
		{
			/* Add custom routine here to handle the case where software causes CPU reset */
		}
#endif
@@USERCODE

	}
	else if ((SYS_EXCEPTION & SW_RESET) != 0)
	{
		/* Reset caused due to software reset.
		Add user code to handle software reset. */

@@USERCODE
	}
	else
	{
		/* Reset caused by nRST being driven low externally.
		Add user code to handle external reset. */

@@USERCODE
	}

	/* Check if there were ESM group3 errors during power-up.
	 * These could occur during eFuse auto-load or during reads from flash OTP
	 * during power-up. Device operation is not reliable and not recommended
	 * in this case.
	 * An ESM group3 error only drives the nERROR pin low. An external circuit
	 * that monitors the nERROR pin must take the appropriate action to ensure that
	 * the system is placed in a safe state, as determined by the application.
	 */
	if (esmREG->ESTATUS1[2])
	{
	/* while(1) can be removed by adding "# if 0" and "# endif" in the user codes above and below */
@@USERCODE
        while(1);
@@USERCODE
	}

@@USERCODE

    /* Initialize System - Clock, Flash settings with Efuse self check */
	systemInit();

#if %%SYSTEM:SAFETY_INIT_STC_CPUSELFTEST_ENA%%
@@USERCODE

	/* Make sure that the CPU self-test controller can actually detect a fault inside CPU */
	stcSelfCheck();

@@USERCODE
}

void afterSTC(void)
{
#endif

@@USERCODE

#if %%SYSTEM:SAFETY_INIT_CCM_SELFCHECK_ENA%%
	/* Make sure that CCM-R4F is working as expected.
	 * This function puts the CCM-R4F module through its self-test modes.
	 * It ensures that the CCM-R4F is indeed capable of detecting a CPU mismatch,
	 * and is also capable of indicating a mismatch error to the ESM.
	 */
	ccmSelfCheck();

@@USERCODE
#endif

#if %%SYSTEM:SAFETY_INIT_PBIST_SELFCHECK_ENA%%
	/* Run a diagnostic check on the memory self-test controller.
	 * This function chooses a RAM test algorithm and runs it on an on-chip ROM.
	 * The memory self-test is expected to fail. The function ensures that the PBIST controller
	 * is capable of detecting and indicating a memory self-test failure.
	 */
	pbistSelfCheck();

@@USERCODE
#endif

#if %%SYSTEM:SAFETY_INIT_PBIST_ESRAM_SELECTED%%

	/* Run PBIST on CPU RAM.
	 * The PBIST controller needs to be configured separately for single-port and dual-port SRAMs.
	 * The CPU RAM is a single-port memory. The actual "RAM Group" for all on-chip SRAMs is defined in the
	 * device datasheet.
	 */
	pbistRun(%%SYSTEM:SAFETY_INIT_ESRAM_SP_PBISTCHECK_ENA%%, /* ESRAM Single Port PBIST */
             PBIST_March13N_SP);

@@USERCODE

	/* Wait for PBIST for CPU RAM to be completed */
	while(!pbistIsTestCompleted());

@@USERCODE

	/* Check if CPU RAM passed the self-test */
	if( pbistIsTestPassed() != TRUE)
	{
		/* CPU RAM failed the self-test.
		 * Need custom handler to check the memory failure
		 * and to take the appropriate next step.
		 */
		if(pbistPortTestStatus(PBIST_PORT0) != TRUE)
		{
            memoryPort0TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA0, pbistREG->FSRDL0);
		}
        else if(pbistPortTestStatus(PBIST_PORT1) != TRUE)
		{
            memoryPort1TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA1, pbistREG->FSRDL1);
		}
		else
		{
		/* while(1) can be removed by adding "# if 0" and "# endif" in the user codes above and below */
@@USERCODE
		   while(1);
@@USERCODE	
		}
	}

@@USERCODE

	/* Disable PBIST clocks and disable memory self-test mode */
	pbistStop();
	
#endif

@@USERCODE

#if %%SYSTEM:RAM_ECC_ENABLE%%

	/* Initialize CPU RAM.
	 * This function uses the system module's hardware for auto-initialization of memories and their
	 * associated protection schemes. The CPU RAM is initialized by setting bit 0 of the MSIENA register.
	 * Hence the value 0x1 passed to the function.
	 * This function will initialize the entire CPU RAM and the corresponding ECC locations.
	 */
	_memoryInit_(0x1);

@@USERCODE
	
	/* Enable ECC checking for TCRAM accesses.
	 * This function enables the CPU's ECC logic for accesses to B0TCM and B1TCM.
	 */
	_coreEnableRamEcc_();

@@USERCODE

#endif

#if %%SYSTEM:SAFETY_INIT_PBIST_DP_SELECTED%%
	/* Start PBIST on all dual-port memories */
	/* NOTE : Please Refer DEVICE DATASHEET for the list of Supported Dual port Memories.
	   PBIST test perfomed only on the user selected memories in HALCoGen's GUI SAFETY INIT tab.
	 */
	
    pbistRun(  %%SYSTEM:SAFETY_INIT_EMAC_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_USB_DP_PBISTCHECK_ENA%%         
			 | %%SYSTEM:SAFETY_INIT_DMA_DP_PBISTCHECK_ENA%%    
             | %%SYSTEM:SAFETY_INIT_VIM1_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_MIBSPI1_DP_PBISTCHECK_ENA%%
             | %%SYSTEM:SAFETY_INIT_MIBSPI3_DP_PBISTCHECK_ENA%%
             | %%SYSTEM:SAFETY_INIT_MIBSPI5_DP_PBISTCHECK_ENA%%
             | %%SYSTEM:SAFETY_INIT_CAN1_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_CAN2_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_CAN3_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_ADC1_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_ADC2_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_HET1_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_HET2_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_HTU1_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_HTU2_DP_PBISTCHECK_ENA%%   
             | %%SYSTEM:SAFETY_INIT_RTP_DP_PBISTCHECK_ENA%%    
			 | %%SYSTEM:SAFETY_INIT_FTU_DP_PBISTCHECK_ENA%%    
			 | %%SYSTEM:SAFETY_INIT_FRAY_DP_PBISTCHECK_ENA%%   
			 , PBIST_March13N_DP);

@@USERCODE
#endif

#if %%SYSTEM:SAFETY_INIT_RAMECC_SELFCHECK_ENA%%

	/* Test the CPU ECC mechanism for RAM accesses.
	 * The checkBxRAMECC functions cause deliberate single-bit and double-bit errors in TCRAM accesses
	 * by corrupting 1 or 2 bits in the ECC. Reading from the TCRAM location with a 2-bit error
	 * in the ECC causes a data abort exception. The data abort handler is written to look for
	 * deliberately caused exception and to return the code execution to the instruction
	 * following the one that caused the abort.
	 */
	checkB0RAMECC();
	tcram1REG->RAMCTRL &= ~(0x00000100);				/* disable writes to ECC RAM */
	tcram2REG->RAMCTRL &= ~(0x00000100);

	checkB1RAMECC();
	tcram1REG->RAMCTRL &= ~(0x00000100);				/* disable writes to ECC RAM */
	tcram2REG->RAMCTRL &= ~(0x00000100);

@@USERCODE
#endif

#if %%SYSTEM:SAFETY_INIT_FLASHECC_SELFCHECK_ENA%%

	/* Test the CPU ECC mechanism for Flash accesses.
	 * The checkFlashECC function uses the flash interface module's diagnostic mode 7
	 * to create single-bit and double-bit errors in CPU accesses to the flash. A double-bit
	 * error on reading from flash causes a data abort exception.
	 * The data abort handler is written to look for deliberately caused exception and
	 * to return the code execution to the instruction following the one that was aborted.
	 *
	 */
	checkFlashECC();
	flashWREG->FDIAGCTRL = 0x000A0007;					/* disable flash diagnostic mode */

@@USERCODE
#endif

#if %%SYSTEM:SAFETY_INIT_PBIST_DP_SELECTED%%
@@USERCODE

	/* Wait for PBIST for CPU RAM to be completed */
	while(!pbistIsTestCompleted());

@@USERCODE

	/* Check if CPU RAM passed the self-test */
	if( pbistIsTestPassed() != TRUE)
	{

@@USERCODE

        /* CPU RAM failed the self-test.
		 * Need custom handler to check the memory failure
		 * and to take the appropriate next step.
		 */
		if(pbistPortTestStatus(PBIST_PORT0) != TRUE)
		{
            memoryPort0TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA0, pbistREG->FSRDL0);
		}
        else if(pbistPortTestStatus(PBIST_PORT1) != TRUE)
		{
            memoryPort1TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA1, pbistREG->FSRDL1);
		}
		else
		{
		/* while(1) can be removed by adding "# if 0" and "# endif" in the user codes above and below */
@@USERCODE
		   while(1);
@@USERCODE	
		}
	}

@@USERCODE

	/* Disable PBIST clocks and disable memory self-test mode */
	pbistStop();
	
#endif

#if %%SYSTEM:SAFETY_INIT_PBIST_SP_SELECTED%%
@@USERCODE

	/* Test the single-port RAMs excluding the CPU RAM
	* which was tested before and passed.
    */
	/* NOTE : Please Refer DEVICE DATASHEET for the list of Supported Single port Memories.
	   PBIST test perfomed only on the user selected memories in HALCoGen's GUI SAFETY INIT tab.
	*/
    pbistRun(  %%SYSTEM:SAFETY_INIT_EMAC_SP_PBISTCHECK_ENA%%
             | %%SYSTEM:SAFETY_INIT_USB_SP_PBISTCHECK_ENA%% 
			 | %%SYSTEM:SAFETY_INIT_FRAY_SP_PBISTCHECK_ENA%%
			 , PBIST_March13N_SP);
	
@@USERCODE

	/* Wait for PBIST for CPU RAM to be completed */
	while(!pbistIsTestCompleted());

@@USERCODE

	/* Check if CPU RAM passed the self-test */
	if( pbistIsTestPassed() != TRUE)
	{

@@USERCODE

	    /* CPU RAM failed the self-test.
		 * Need custom handler to check the memory failure
		 * and to take the appropriate next step.
		 */
		if(pbistPortTestStatus(PBIST_PORT0) != TRUE)
		{
            memoryPort0TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA0, pbistREG->FSRDL0);
		}
        else if(pbistPortTestStatus(PBIST_PORT1) != TRUE)
		{
            memoryPort1TestFailNotification(pbistREG->RGS, pbistREG->RDS, pbistREG->FSRA1, pbistREG->FSRDL1);
		}
		else
		{
		/* while(1) can be removed by adding "# if 0" and "# endif" in the user codes above and below */
@@USERCODE
		   while(1);
@@USERCODE		
		}
	}

@@USERCODE

	/* Disable PBIST clocks and disable memory self-test mode */
	pbistStop();

#endif

@@USERCODE

#if %%SYSTEM:SAFETY_INIT_MIBSPI1_RAMPARITYCHECK_ENA%%
	/* Release the MibSPI1 modules from local reset.
	 * This will cause the MibSPI1 RAMs to get initialized along with the parity memory.
	 */
	 mibspiREG1->GCR0 = 0x1;
	 
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI3_RAMPARITYCHECK_ENA%%	 
	/* Release the MibSPI3 modules from local reset.
	 * This will cause the MibSPI3 RAMs to get initialized along with the parity memory.
	 */
	mibspiREG3->GCR0 = 0x1;
	
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI5_RAMPARITYCHECK_ENA%%	
	/* Release the MibSPI5 modules from local reset.
	 * This will cause the MibSPI5 RAMs to get initialized along with the parity memory.
	 */
	mibspiREG5->GCR0 = 0x1;
	
#endif
#if %%SYSTEM:SAFETY_INIT_MEMINIT_SELECTED%%	
@@USERCODE

    /* Initialize all on-chip SRAMs except for MibSPIx RAMs
     * The MibSPIx modules have their own auto-initialization mechanism which is triggered
     * as soon as the modules are brought out of local reset.
     */
	/* The system module auto-init will hang on the MibSPI RAM if the module is still in local reset.
	 */
	/* NOTE : Please Refer DEVICE DATASHEET for the list of Supported Memories and their channel numbers.
		      Memory Initialization is perfomed only on the user selected memories in HALCoGen's GUI SAFETY INIT tab.
	 */
	_memoryInit_(  %%SYSTEM:SAFETY_INIT_DMA_RAMPARITYCHECK_ENA%% << 1   
                 | %%SYSTEM:SAFETY_INIT_VIM1_RAMPARITYCHECK_ENA%% << 2  
                 | %%SYSTEM:SAFETY_INIT_CAN1_RAMPARITYCHECK_ENA%% << 5  
                 | %%SYSTEM:SAFETY_INIT_CAN2_RAMPARITYCHECK_ENA%% << 6  
                 | %%SYSTEM:SAFETY_INIT_CAN3_RAMPARITYCHECK_ENA%% << 10 
                 | %%SYSTEM:SAFETY_INIT_ADC1_RAMPARITYCHECK_ENA%% << 8  
                 | %%SYSTEM:SAFETY_INIT_ADC2_RAMPARITYCHECK_ENA%% << 14 
                 | %%SYSTEM:SAFETY_INIT_HET1_RAMPARITYCHECK_ENA%% << 3  
                 | %%SYSTEM:SAFETY_INIT_HTU1_RAMPARITYCHECK_ENA%% << 4  
                 | %%SYSTEM:SAFETY_INIT_HET2_RAMPARITYCHECK_ENA%% << 15 
                 | %%SYSTEM:SAFETY_INIT_HTU2_RAMPARITYCHECK_ENA%% << 16 
                 | %%SYSTEM:SAFETY_INIT_FTU_RAMPARITYCHECK_ENA%% << 13);

	/* Test the parity protection mechanism for peripheral RAMs
	   NOTE : Please Refer DEVICE DATASHEET for the list of Supported Memories with parity.
	   	      Parity Self check is perfomed only on the user selected memories in HALCoGen's GUI SAFETY INIT tab.
	*/

#endif 
#if %%SYSTEM:SAFETY_INIT_HET1_RAMPARITYCHECK_ENA%%
@@USERCODE
	 
	het1ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_HTU1_RAMPARITYCHECK_ENA%%
@@USERCODE

	htu1ParityCheck();
	
#endif	
#if %%SYSTEM:SAFETY_INIT_HET2_RAMPARITYCHECK_ENA%%
@@USERCODE

	het2ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_HTU2_RAMPARITYCHECK_ENA%%
@@USERCODE

	htu2ParityCheck();
	
#endif	
#if %%SYSTEM:SAFETY_INIT_ADC1_RAMPARITYCHECK_ENA%%
@@USERCODE	

	adc1ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_ADC2_RAMPARITYCHECK_ENA%%
@@USERCODE

	adc2ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_CAN1_RAMPARITYCHECK_ENA%%
@@USERCODE

	can1ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_CAN2_RAMPARITYCHECK_ENA%%
@@USERCODE

	can2ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_CAN3_RAMPARITYCHECK_ENA%%
@@USERCODE

	can3ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_VIM1_RAMPARITYCHECK_ENA%%
@@USERCODE

	vimParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_DMA_RAMPARITYCHECK_ENA%%
@@USERCODE

	dmaParityCheck();

#endif

@@USERCODE

#if %%SYSTEM:SAFETY_INIT_MIBSPI1_RAMPARITYCHECK_ENA%%
	while (mibspiREG1->BUFINIT);		/* wait for MibSPI1 RAM to complete initialization */
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI3_RAMPARITYCHECK_ENA%%	
	while (mibspiREG3->BUFINIT);		/* wait for MibSPI3 RAM to complete initialization */ 
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI5_RAMPARITYCHECK_ENA%%	
	while (mibspiREG5->BUFINIT);		/* wait for MibSPI5 RAM to complete initialization */
#endif

#if %%SYSTEM:SAFETY_INIT_MIBSPI1_RAMPARITYCHECK_ENA%%
@@USERCODE

	mibspi1ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI3_RAMPARITYCHECK_ENA%%
@@USERCODE

	mibspi3ParityCheck();
	
#endif
#if %%SYSTEM:SAFETY_INIT_MIBSPI5_RAMPARITYCHECK_ENA%%
@@USERCODE
	
	mibspi5ParityCheck();
	
#endif

@@USERCODE
	
#if %%CORE_IRQ_VIC_ENABLE%%
    /* Enable IRQ offset via Vic controller */
    _coreEnableIrqVicOffset_();
	
#endif

@@USERCODE

	
#if %%VIM_CONFIG_NEW%%
    /* Initialize VIM table */
    {
        uint32_t i;

        for (i = 0; i < (VIM_CHANNELS + 1); i++)
        {
            vimRAM->ISR[i] = s_vim_init[i];
        }
    }

    /* set IRQ/FIQ priorities */
    vimREG->FIRQPR0 =  SYS_%%SYSTEM:VIM_CHANNEL_0_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_1_INT_TYPE%% <<  1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_2_INT_TYPE%% <<  2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_3_INT_TYPE%% <<  3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_4_INT_TYPE%% <<  4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_5_INT_TYPE%% <<  5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_6_INT_TYPE%% <<  6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_7_INT_TYPE%% <<  7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_8_INT_TYPE%% <<  8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_9_INT_TYPE%% <<  9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_10_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_11_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_12_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_13_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_14_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_15_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_16_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_17_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_18_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_19_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_20_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_21_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_22_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_23_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_24_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_25_INT_TYPE%% << 25U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_26_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_27_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_28_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_29_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_30_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_31_INT_TYPE%% << 31U);

    vimREG->FIRQPR1 =  SYS_%%SYSTEM:VIM_CHANNEL_32_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_33_INT_TYPE%% <<  1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_34_INT_TYPE%% <<  2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_35_INT_TYPE%% <<  3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_36_INT_TYPE%% <<  4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_37_INT_TYPE%% <<  5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_38_INT_TYPE%% <<  6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_39_INT_TYPE%% <<  7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_40_INT_TYPE%% <<  8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_41_INT_TYPE%% <<  9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_42_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_43_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_44_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_45_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_46_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_47_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_48_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_49_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_50_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_51_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_52_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_53_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_54_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_55_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_56_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_57_INT_TYPE%% << 25U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_58_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_59_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_60_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_61_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_62_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_63_INT_TYPE%% << 31U);


    vimREG->FIRQPR2 =  SYS_%%SYSTEM:VIM_CHANNEL_64_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_65_INT_TYPE%% << 1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_66_INT_TYPE%% << 2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_67_INT_TYPE%% << 3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_68_INT_TYPE%% << 4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_69_INT_TYPE%% << 5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_70_INT_TYPE%% << 6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_71_INT_TYPE%% << 7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_72_INT_TYPE%% << 8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_73_INT_TYPE%% << 9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_74_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_75_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_76_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_77_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_78_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_79_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_80_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_81_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_82_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_83_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_84_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_85_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_86_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_87_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_88_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_89_INT_TYPE%% << 25U)
					| (SYS_%%SYSTEM:VIM_CHANNEL_90_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_91_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_92_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_93_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_94_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_95_INT_TYPE%% << 31U);

    vimREG->FIRQPR3 =  SYS_%%SYSTEM:VIM_CHANNEL_96_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_97_INT_TYPE%% << 1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_98_INT_TYPE%% << 2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_99_INT_TYPE%% << 3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_100_INT_TYPE%% << 4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_101_INT_TYPE%% << 5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_102_INT_TYPE%% << 6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_103_INT_TYPE%% << 7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_104_INT_TYPE%% << 8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_105_INT_TYPE%% << 9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_106_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_107_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_108_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_109_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_110_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_111_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_112_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_113_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_114_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_115_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_116_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_117_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_118_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_119_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_120_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_121_INT_TYPE%% << 25U)
					| (SYS_%%SYSTEM:VIM_CHANNEL_122_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_123_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_124_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_125_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_126_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_127_INT_TYPE%% << 31U);

					
    /* enable interrupts */
    vimREG->REQMASKSET0 = %%SYSTEM:VIM_CHANNEL_0_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_1_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_2_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_3_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_4_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_5_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_6_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_7_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_8_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_9_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_10_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_11_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_12_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_13_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_14_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_15_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_16_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_17_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_18_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_19_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_20_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_21_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_22_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_23_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_24_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_25_INT_ENABLE%%U << 25U)
                        | (%%SYSTEM:VIM_CHANNEL_26_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_27_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_28_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_29_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_30_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_31_INT_ENABLE%%U << 31U);

    vimREG->REQMASKSET1 = %%SYSTEM:VIM_CHANNEL_32_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_33_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_34_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_35_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_36_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_37_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_38_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_39_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_40_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_41_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_42_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_43_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_44_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_45_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_46_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_47_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_48_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_49_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_50_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_51_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_52_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_53_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_54_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_55_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_56_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_57_INT_ENABLE%%U << 25U)
                        | (%%SYSTEM:VIM_CHANNEL_58_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_59_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_60_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_61_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_62_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_63_INT_ENABLE%%U << 31U);

    vimREG->REQMASKSET2 = %%SYSTEM:VIM_CHANNEL_64_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_65_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_66_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_67_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_68_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_69_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_70_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_71_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_72_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_73_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_74_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_75_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_76_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_77_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_78_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_79_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_80_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_81_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_82_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_83_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_84_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_85_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_86_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_87_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_88_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_89_INT_ENABLE%%U << 25U)
					    | (%%SYSTEM:VIM_CHANNEL_90_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_91_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_92_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_93_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_94_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_95_INT_ENABLE%%U << 31U);
						
    vimREG->REQMASKSET3 =  %%SYSTEM:VIM_CHANNEL_96_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_97_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_98_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_99_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_100_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_101_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_102_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_103_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_104_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_105_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_106_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_107_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_108_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_109_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_110_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_111_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_112_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_113_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_114_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_115_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_116_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_117_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_118_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_119_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_120_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_121_INT_ENABLE%%U << 25U)
						| (%%SYSTEM:VIM_CHANNEL_122_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_123_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_124_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_125_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_126_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_127_INT_ENABLE%%U << 31U);	
#endif

@@USERCODE

	/* Configure system response to error conditions signaled to the ESM group1 */
	/* This function can be configured from the ESM tab of HALCoGen */
	esmInit();

#if %%TOOLS:TI%%
    /* initialize copy table */
    if ((uint32_t *)&__binit__ != (uint32_t *)0xFFFFFFFFU)
    {
        extern void copy_in(void *binit);
        copy_in((void *)&__binit__);
    }

    /* initialize the C global variables */
    if (&__TI_Handler_Table_Base < &__TI_Handler_Table_Limit)
    {
        uint8_t **tablePtr   = (uint8_t **)&__TI_CINIT_Base;
        uint8_t **tableLimit = (uint8_t **)&__TI_CINIT_Limit;

        while (tablePtr < tableLimit)
        {
            uint8_t *loadAdr = *tablePtr++;
            uint8_t *runAdr  = *tablePtr++;
            uint8_t  idx     = *loadAdr++;
            handler_fptr   handler = (handler_fptr)(&__TI_Handler_Table_Base)[idx];

            (*handler)((const uint8_t *)loadAdr, runAdr);
        }
    }

    /* initialize constructors */
    if (__TI_PINIT_Base < __TI_PINIT_Limit)
    {
        void (**p0)() = (void *)__TI_PINIT_Base;

        while ((uint32_t)p0 < __TI_PINIT_Limit)
        {
            void (*p)() = *p0++;
            p();
        }
    }
#endif

@@USERCODE
	
    /* call the application */
#if %%TOOLS:TI%%
    main();

@@USERCODE

    exit();
#endif
#if %%TOOLS:ARM%%
    __main();
#endif
#if %%TOOLS:IAR%%
    __cmain();
#endif
@@USERCODE
}

@@USERCODE


void vimInit(void)
{	
#if %%VIM_CONFIG_NEW%%
    /* Initialize VIM table */
    {
        uint32_t i;

        for (i = 0; i < (VIM_CHANNELS + 1); i++)
        {
            vimRAM->ISR[i] = s_vim_init[i];
        }
    }

    /* set IRQ/FIQ priorities */
    vimREG->FIRQPR0 =  SYS_%%SYSTEM:VIM_CHANNEL_0_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_1_INT_TYPE%% <<  1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_2_INT_TYPE%% <<  2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_3_INT_TYPE%% <<  3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_4_INT_TYPE%% <<  4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_5_INT_TYPE%% <<  5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_6_INT_TYPE%% <<  6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_7_INT_TYPE%% <<  7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_8_INT_TYPE%% <<  8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_9_INT_TYPE%% <<  9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_10_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_11_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_12_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_13_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_14_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_15_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_16_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_17_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_18_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_19_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_20_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_21_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_22_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_23_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_24_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_25_INT_TYPE%% << 25U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_26_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_27_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_28_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_29_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_30_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_31_INT_TYPE%% << 31U);

    vimREG->FIRQPR1 =  SYS_%%SYSTEM:VIM_CHANNEL_32_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_33_INT_TYPE%% <<  1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_34_INT_TYPE%% <<  2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_35_INT_TYPE%% <<  3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_36_INT_TYPE%% <<  4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_37_INT_TYPE%% <<  5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_38_INT_TYPE%% <<  6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_39_INT_TYPE%% <<  7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_40_INT_TYPE%% <<  8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_41_INT_TYPE%% <<  9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_42_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_43_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_44_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_45_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_46_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_47_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_48_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_49_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_50_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_51_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_52_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_53_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_54_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_55_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_56_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_57_INT_TYPE%% << 25U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_58_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_59_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_60_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_61_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_62_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_63_INT_TYPE%% << 31U);


    vimREG->FIRQPR2 =  SYS_%%SYSTEM:VIM_CHANNEL_64_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_65_INT_TYPE%% << 1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_66_INT_TYPE%% << 2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_67_INT_TYPE%% << 3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_68_INT_TYPE%% << 4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_69_INT_TYPE%% << 5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_70_INT_TYPE%% << 6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_71_INT_TYPE%% << 7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_72_INT_TYPE%% << 8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_73_INT_TYPE%% << 9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_74_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_75_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_76_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_77_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_78_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_79_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_80_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_81_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_82_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_83_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_84_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_85_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_86_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_87_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_88_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_89_INT_TYPE%% << 25U)
					| (SYS_%%SYSTEM:VIM_CHANNEL_90_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_91_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_92_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_93_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_94_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_95_INT_TYPE%% << 31U);

    vimREG->FIRQPR3 =  SYS_%%SYSTEM:VIM_CHANNEL_96_INT_TYPE%%
                    | (SYS_%%SYSTEM:VIM_CHANNEL_97_INT_TYPE%% << 1U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_98_INT_TYPE%% << 2U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_99_INT_TYPE%% << 3U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_100_INT_TYPE%% << 4U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_101_INT_TYPE%% << 5U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_102_INT_TYPE%% << 6U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_103_INT_TYPE%% << 7U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_104_INT_TYPE%% << 8U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_105_INT_TYPE%% << 9U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_106_INT_TYPE%% << 10U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_107_INT_TYPE%% << 11U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_108_INT_TYPE%% << 12U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_109_INT_TYPE%% << 13U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_110_INT_TYPE%% << 14U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_111_INT_TYPE%% << 15U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_112_INT_TYPE%% << 16U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_113_INT_TYPE%% << 17U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_114_INT_TYPE%% << 18U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_115_INT_TYPE%% << 19U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_116_INT_TYPE%% << 20U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_117_INT_TYPE%% << 21U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_118_INT_TYPE%% << 22U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_119_INT_TYPE%% << 23U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_120_INT_TYPE%% << 24U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_121_INT_TYPE%% << 25U)
					| (SYS_%%SYSTEM:VIM_CHANNEL_122_INT_TYPE%% << 26U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_123_INT_TYPE%% << 27U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_124_INT_TYPE%% << 28U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_125_INT_TYPE%% << 29U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_126_INT_TYPE%% << 30U)
                    | (SYS_%%SYSTEM:VIM_CHANNEL_127_INT_TYPE%% << 31U);

					
    /* enable interrupts */
    vimREG->REQMASKSET0 = %%SYSTEM:VIM_CHANNEL_0_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_1_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_2_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_3_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_4_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_5_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_6_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_7_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_8_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_9_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_10_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_11_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_12_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_13_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_14_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_15_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_16_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_17_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_18_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_19_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_20_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_21_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_22_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_23_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_24_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_25_INT_ENABLE%%U << 25U)
                        | (%%SYSTEM:VIM_CHANNEL_26_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_27_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_28_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_29_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_30_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_31_INT_ENABLE%%U << 31U);

    vimREG->REQMASKSET1 = %%SYSTEM:VIM_CHANNEL_32_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_33_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_34_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_35_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_36_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_37_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_38_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_39_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_40_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_41_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_42_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_43_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_44_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_45_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_46_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_47_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_48_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_49_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_50_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_51_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_52_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_53_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_54_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_55_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_56_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_57_INT_ENABLE%%U << 25U)
                        | (%%SYSTEM:VIM_CHANNEL_58_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_59_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_60_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_61_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_62_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_63_INT_ENABLE%%U << 31U);

    vimREG->REQMASKSET2 = %%SYSTEM:VIM_CHANNEL_64_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_65_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_66_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_67_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_68_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_69_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_70_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_71_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_72_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_73_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_74_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_75_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_76_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_77_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_78_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_79_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_80_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_81_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_82_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_83_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_84_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_85_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_86_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_87_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_88_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_89_INT_ENABLE%%U << 25U)
					    | (%%SYSTEM:VIM_CHANNEL_90_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_91_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_92_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_93_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_94_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_95_INT_ENABLE%%U << 31U);
						
    vimREG->REQMASKSET3 =  %%SYSTEM:VIM_CHANNEL_96_INT_ENABLE%%U
                        | (%%SYSTEM:VIM_CHANNEL_97_INT_ENABLE%%U << 1U)
                        | (%%SYSTEM:VIM_CHANNEL_98_INT_ENABLE%%U << 2U)
                        | (%%SYSTEM:VIM_CHANNEL_99_INT_ENABLE%%U << 3U)
                        | (%%SYSTEM:VIM_CHANNEL_100_INT_ENABLE%%U << 4U)
                        | (%%SYSTEM:VIM_CHANNEL_101_INT_ENABLE%%U << 5U)
                        | (%%SYSTEM:VIM_CHANNEL_102_INT_ENABLE%%U << 6U)
                        | (%%SYSTEM:VIM_CHANNEL_103_INT_ENABLE%%U << 7U)
                        | (%%SYSTEM:VIM_CHANNEL_104_INT_ENABLE%%U << 8U)
                        | (%%SYSTEM:VIM_CHANNEL_105_INT_ENABLE%%U << 9U)
                        | (%%SYSTEM:VIM_CHANNEL_106_INT_ENABLE%%U << 10U)
                        | (%%SYSTEM:VIM_CHANNEL_107_INT_ENABLE%%U << 11U)
                        | (%%SYSTEM:VIM_CHANNEL_108_INT_ENABLE%%U << 12U)
                        | (%%SYSTEM:VIM_CHANNEL_109_INT_ENABLE%%U << 13U)
                        | (%%SYSTEM:VIM_CHANNEL_110_INT_ENABLE%%U << 14U)
                        | (%%SYSTEM:VIM_CHANNEL_111_INT_ENABLE%%U << 15U)
                        | (%%SYSTEM:VIM_CHANNEL_112_INT_ENABLE%%U << 16U)
                        | (%%SYSTEM:VIM_CHANNEL_113_INT_ENABLE%%U << 17U)
                        | (%%SYSTEM:VIM_CHANNEL_114_INT_ENABLE%%U << 18U)
                        | (%%SYSTEM:VIM_CHANNEL_115_INT_ENABLE%%U << 19U)
                        | (%%SYSTEM:VIM_CHANNEL_116_INT_ENABLE%%U << 20U)
                        | (%%SYSTEM:VIM_CHANNEL_117_INT_ENABLE%%U << 21U)
                        | (%%SYSTEM:VIM_CHANNEL_118_INT_ENABLE%%U << 22U)
                        | (%%SYSTEM:VIM_CHANNEL_119_INT_ENABLE%%U << 23U)
                        | (%%SYSTEM:VIM_CHANNEL_120_INT_ENABLE%%U << 24U)
                        | (%%SYSTEM:VIM_CHANNEL_121_INT_ENABLE%%U << 25U)
						| (%%SYSTEM:VIM_CHANNEL_122_INT_ENABLE%%U << 26U)
                        | (%%SYSTEM:VIM_CHANNEL_123_INT_ENABLE%%U << 27U)
                        | (%%SYSTEM:VIM_CHANNEL_124_INT_ENABLE%%U << 28U)
                        | (%%SYSTEM:VIM_CHANNEL_125_INT_ENABLE%%U << 29U)
                        | (%%SYSTEM:VIM_CHANNEL_126_INT_ENABLE%%U << 30U)
                        | (%%SYSTEM:VIM_CHANNEL_127_INT_ENABLE%%U << 31U);	
#endif

@@USERCODE
}
