#include <sl_types.h>
#include <sl_config.h>
#include <sl_priv.h>


boolean sl_priv_flag_set[TESTTYPE_MAX - TESTTYPE_MIN] = {0};

boolean SL_FLAG_SET(uint8 flag_id) {
    sl_priv_flag_set[flag_id-TESTTYPE_MIN] = TRUE;
    return sl_priv_flag_set[flag_id];
}

void SL_FLAG_CLEAR(uint8 flag_id) {
    sl_priv_flag_set[flag_id-TESTTYPE_MIN] = FALSE;
}
boolean SL_FLAG_GET(uint8 flag_id) {
    return sl_priv_flag_set[flag_id-TESTTYPE_MIN];
}

/*SAFETYMCUSW 91 S MR: 5.2,5.6,5.7 <APPROVED> "Name declared in another C name space is deviated" */
void _SL_SelfTest_SRAM_RAD (sl_tcramBASE_t *ramBase, SL_SelfTest_Result * rad_stResult)
{
    /** Start with the equality test scheme **/
    ramBase->RAMTEST = (uint32) 0x0000018Au; /* 1->Trigger, 8->Eq., test mode, A->Test enable */
    /* Wait for the test to complete */
    /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
    while (TCRAM_RAMTEST_TST_TRIGGER == (TCRAM_RAMTEST_TST_TRIGGER & ramBase->RAMTEST)) {

	}
    if (TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL == \
        (ramBase->RAMERRSTATUS & TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL)) {
        /* Test failed */
    	/* Clear the error status */
    	ramBase->RAMERRSTATUS |= TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL;
        *rad_stResult = ST_FAIL;
    } else {
        ramBase->RAMTEST = 0x0000014Au; /* 1->Trigger, 4->UnEq., test mode, A->Test enable */
        /* Wait for the test to complete */
        /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
        while (TCRAM_RAMTEST_TST_TRIGGER == (TCRAM_RAMTEST_TST_TRIGGER & ramBase->RAMTEST))
        {

        }
        if (TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL == \
            (ramBase->RAMERRSTATUS & TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL)) {
            /* Test failed */
        	/* Clear the error status */
			ramBase->RAMERRSTATUS |= TCRAM_RAMERRSTATUS_ADDR_CMP_LG_FAIL;
            *rad_stResult = ST_FAIL;
        } else {
        	ramBase->RAMERRSTATUS |= TCRAM_RAMERRSTATUS_ADDR_DEC_FAIL;
            *rad_stResult = ST_PASS;
        }
    }
}


/** @fn void SL_SelfTest_adcGetSingleData(sl_adcBASE_t *adc, unsigned group, adcData_t *data)
 *   @brief Get single converted ADC value
 *   @param[in] adc Pointer to ADC module:
 *              - sl_adcREG1: ADC1 module pointer
 *              - sl_adcREG2: ADC2 module pointer
 *              - adcREG3: ADC3 module pointer
 *   @param[in] group Hardware group of ADC module:
 *              - adcGROUP0: ADC event group
 *              - adcGROUP1: ADC group 1
 *              - adcGROUP2: ADC group 2
 *   @param[out] data Pointer to store ADC converted data
 *
 */
boolean _SL_SelfTest_adcGetSingleData(sl_adcBASE_t *adc, uint32 group, SL_ADC_Data *data)
{
    boolean retVal = TRUE;
	uint32 buf;

    if((adc != sl_adcREG1) && (adc != sl_adcREG2) && (adc != NULL) && (data != NULL)) {
        retVal =  FALSE;
    }
    else
    {
		SL_ADC_Data *ptr = data;

		/** -  Get conversion data and channel/pin id */
		buf = adc->GxBUF[group].BUF0;
		ptr->value = ((uint16)(((uint32)buf)&(ADC_VALUE_MASK)));
		ptr->id = ADC_GET_CHANNEL_ID(buf); /* int to unsigned short*/
		/*Clear the flags which are set by writing 1 to those bit fields*/
		adc->GxINTFLG[group] = ADC_GROUP_THR_INT_FLG | ADC_GROUP_CONV_END;

		/**   @note The function adcInit has to be called before this function can be used.\n
		 *           The user is responsible to initialize the message box.
		 */
    }
	return retVal;
}

/** @fn void SL_SelfTest_adcStartConversion_selChn(sl_adcBASE_t *adc, unsigned channel, unsigned fifo_size, unsigned group)
 *   @brief Starts an ADC conversion
 *   @param[in] adc Pointer to ADC module:
 *              - sl_adcREG1: ADC1 module pointer
 *              - sl_adcREG2: ADC2 module pointer
 *   @param[in] channel ADC channel to be selected for conversion
 *   @param[in] fifo_size ADC fifo size to be configured.
 *   @param[in] group Hardware group of ADC module:
 *              - adcGROUP0: ADC event group
 *              - adcGROUP1: ADC group 1
 *              - adcGROUP2: ADC group 2
 *
 *   This function Starts the convesion of the ADC selected group for the selected channel
 *
 */
boolean _SL_SelfTest_adcStartConversion_selChn(sl_adcBASE_t *adc, uint8 channel, uint32 fifo_size, uint32 group)
{
    boolean retVal = TRUE;
    if((adc != sl_adcREG1) && (adc != sl_adcREG2) && (adc != NULL)) {
        retVal =  FALSE;
    }
    else
    {
	/** - Setup FiFo size */
	adc->GxINTCR[group] = fifo_size;
	/** - Start Conversion */
	adc->GxSEL[group] = 1u << channel;
    }
    return retVal;
}

/** @fn boolean SL_SelfTest_adcIsConversionComplete(sl_adcBASE_t *adc, uint32 group)
 *   @brief Checks if Conversion is complete
 *   @param[in] adc Pointer to ADC module:
 *              - sl_adcREG1: ADC1 module pointer
 *              - sl_adcREG2: ADC2 module pointer
 *              - adcREG3: ADC3 module pointer
 *   @param[in] group Hardware group of ADC module:
 *              - adcGROUP0: ADC event group
 *              - adcGROUP1: ADC group 1
 *              - adcGROUP2: ADC group 2
 *   @return The function will return:
 *           - 0: When is not finished
 *           - 8: When conversion is complete
 *
 *   This function checks if conversion is complete.
 *
 */
boolean _SL_SelfTest_adcIsConversionComplete(const sl_adcBASE_t *adc, uint32 group)
{
	uint32 flags;
	boolean retVal;

	
	
    if((adc != sl_adcREG1) && (adc != sl_adcREG2) && (adc != NULL)) {
        retVal =  FALSE;
    }
    else
    {
		/** - Read conversion flags */
		flags = adc->GxINTFLG[group] & ADC_GROUP_CONV_END;

		/**   @note The function adcInit has to be called before this function can be used. */

		
		

		if (ADC_GROUP_CONV_END == flags) {
			retVal=  TRUE;
		} else {
			retVal =  FALSE;
		}
    }
    return retVal;
}

/* \todo need to design & implement this function */
void _SL_HoldNClear_nError(void)
{
    uint32 tempVal = 0u;
    while (tempVal <= NERROR_HOLD_DELAY) {
        tempVal++;
    }
    sl_esmREG->EKR = 0x5u;
    /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
    while(TRUE == SL_ESM_nERROR_Active())
    {

    }
    return;
}



#ifdef LOOP_BACK_ENABLE
void _SL_loadDataPattern(uint16* pptr, uint16 seed_value, uint32 psize)
{
    *pptr = seed_value;
    while((psize--) > 0)
    {
      *pptr = (1u + *pptr++);
    }
}
#endif

uint16  _SL_Approximate_value(uint16 value, uint16 reference, uint8 difference)
{
    uint16 retval;
    if((uint16)(value - reference) < difference)
    {
        retval =  reference;
    }
    else if((uint16)(reference - value) < difference)
    {
        retval =  reference;
    }
    else
    {
        retval =  value;
    }
    return retval;
}
