/*******************************************************************************
 **+--------------------------------------------------------------------------+**
 **|                            ****                                          |**
 **|                            ****                                          |**
 **|                            ******o***                                    |**
 **|                      ********_///_****                                   |**
 **|                      ***** /_//_/ ****                                   |**
 **|                       ** ** (__/ ****                                    |**
 **|                           *********                                      |**
 **|                            ****                                          |**
 **|                            ***                                           |**
 **|                                                                          |**
 **|         Copyright (c) 2012 Texas Instruments Incorporated                |**
 **|                        ALL RIGHTS RESERVED                               |**
 **|                                                                          |**
 **| Permission is hereby granted to licensees of Texas Instruments           |**
 **| Incorporated (TI) products to use this computer program for the sole     |**
 **| purpose of implementing a licensee product based on TI products.         |**
 **| No other rights to reproduce, use, or disseminate this computer          |**
 **| program, whether in part or in whole, are granted.                       |**
 **|                                                                          |**
 **| TI makes no representation or warranties with respect to the             |**
 **| performance of this computer program, and specifically disclaims         |**
 **| any responsibility for any damages, special or consequential,            |**
 **| connected with the use of this program.                                  |**
 **|                                                                          |**
 **+--------------------------------------------------------------------------+**
 *******************************************************************************/
/**
 * @file        sl_selftest.c
 * @version     $$file_version$$
 * @brief       File contains the Self Test APIs
 *
 * @details The file implements the  api's for carrying out selftests and fault injection tests on/n
 * all the peripherals (includes Safety island peripherals also).The utility functions or/n
 * support functions which are used by this file are defined in either sl_misc.c or/n
 * sl_priv.c
 */

#include <sl_api.h>
#include <sl_priv.h>
#define FLASH_DIAG_MODE_ENABLED 0x5U




/*SAFETYMCUSW 69 S MR:3.4 <APPROVED> "Reason -  used for creation of 64 bit aligned sram data array"*/
#pragma DATA_ALIGN(sramEccTestBuff, 64);
volatile uint64 sramEccTestBuff[4] = {0x0u};

/*SAFETYMCUSW 69 S MR:3.4 <APPROVED> "Reason -  used for creation of aligned data section for sramEccTestBuff"*/
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_SRAM(SL_SelfTestType testType, boolean bMode, SL_SelfTest_Result * sram_stResult)
{
	volatile boolean _sl_fault_injection = FALSE;
	boolean retVal = FALSE;
	volatile uint32 regBkupRamTh1, regBkupRamTh2, ramRead, regBkupIntEnaSet, regBckupErrInfulence;
	register uint64 ramread64;
	volatile uint64* eccB1;
	volatile uint64* eccB2;
	volatile uint32 irqStatus;
	register uint32 tempVal;
	register volatile uint64* tcramdataB1;
	register volatile uint64* tcramdataB2;
	register volatile uint64* tcramdataA1;
	register volatile uint64* tcramdataA2;
	uint32 ram1uerraddr,ram2uerraddr;
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
	/*SAFETYMCUSW 94 S MR:11.1 <APPROVED> "Reason -  This is needed,the address is for 64 bit data anyway"*/
	/*SAFETYMCUSW 95 S MR:11.1,11.4- <APPROVED> "Reason -  Implementation constraint"*/
	tcramdataB1 = sramEccTestBuff;
	/*SAFETYMCUSW 95 S MR:11.1,11.4- <APPROVED> "Reason -  Implementation constraint"*/
	/*SAFETYMCUSW 94 S MR:11.1 <APPROVED> "Reason -  This is needed,the address is for 64 bit data anyway"*/
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
	tcramdataB2 = tcramdataB1+1;
	/*SAFETYMCUSW 94 S MR:11.1 <APPROVED> "Reason -  This is needed,the address is for 64 bit data anyway"*/
	/*SAFETYMCUSW 95 S MR:11.1,11.4- <APPROVED> "Reason -  Implementation constraint"*/
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
	tcramdataA1 =  tcramdataB1+2;
	/*SAFETYMCUSW 95 S MR:11.1,11.4- <APPROVED> "Reason -  Implementation constraint"*/
	/*SAFETYMCUSW 94 S MR:11.1 <APPROVED> "Reason -  This is needed,the address is for 64 bit data anyway"*/
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
	tcramdataA2 =  tcramdataB1+3;

	/* If fault inject set global variable to flag to the ESM handler that it is a fault injection */
	if((SRAM_ECC_2BIT_FAULT_INJECT == testType)||
		(SRAM_ECC_1BIT_FAULT_INJECTION == testType)||
		(SRAM_ECC_ERROR_PROFILING_FAULT_INJECT == testType)){
		_sl_fault_injection=TRUE;
	}
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	if ((_SELFTEST_SRAMECC_MIN > testType) || (_SELFTEST_SRAMECC_MAX < testType) ||
			!CHECK_RANGE_RAM_PTR(sram_stResult)) {
		SL_Log_Error(FUNC_ID_ST_SRAM, ERR_TYPE_PARAM, 0U);
		return(FALSE);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	/* Error if not in privilege mode */
	if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
		SL_Log_Error(FUNC_ID_ST_SRAM, ERR_TYPE_ENTRY_CON, 2U);
		return(FALSE);
	}
	/* For MISRA C fix for LDRA - 408S*/
    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
	uint32 tmpRAMCTRL1=sl_tcram1REG->RAMCTRL;
    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
	uint32 tmpRAMCTRL2=sl_tcram2REG->RAMCTRL;
	/* Error if ECC is not enabled */
	if ((SRAM_PAR_ADDR_CTRL_SELF_TEST == testType)
			&& (((SRAM_ADDR_PARITY_DISABLED) == BF_GET(tmpRAMCTRL1, TCRAM_RAMCTRL_ADDR_PAR_DIS_START, TCRAM_RAMCTRL_ADDR_PAR_DIS_LENGTH))
			    || ((SRAM_ADDR_PARITY_DISABLED) == BF_GET(tmpRAMCTRL2, TCRAM_RAMCTRL_ADDR_PAR_DIS_START, TCRAM_RAMCTRL_ADDR_PAR_DIS_LENGTH)))) {
		SL_Log_Error(FUNC_ID_ST_SRAM, ERR_TYPE_ENTRY_CON, 1U);
		return(FALSE);
	}
	if(((SRAM_ECC_ERROR_FORCING_1BIT == testType)||
			(SRAM_ECC_ERROR_FORCING_2BIT == testType)||
			(SRAM_RADECODE_DIAGNOSTICS == testType)) &&
			 (((SRAM_ECC_DISABLED) == BF_GET(tmpRAMCTRL1, TCRAM_RAMCTRL_ECC_DETECT_EN_START, TCRAM_RAMCTRL_ECC_DETECT_EN_LENGTH))
			 	||((SRAM_ECC_DISABLED) == BF_GET(tmpRAMCTRL2, TCRAM_RAMCTRL_ECC_DETECT_EN_START, TCRAM_RAMCTRL_ECC_DETECT_EN_LENGTH)))) {
		SL_Log_Error(FUNC_ID_ST_SRAM, ERR_TYPE_ENTRY_CON, 1U);
		return(FALSE);
	}

	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_SRAM, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif
	retVal = TRUE;      /* Function executed successfully */
	regBkupRamTh1 = sl_tcram1REG->RAMTHRESHOLD;
	regBkupRamTh2 = sl_tcram2REG->RAMTHRESHOLD;
	switch(testType) {
	case SRAM_ECC_ERROR_FORCING_2BIT:
	case SRAM_ECC_2BIT_FAULT_INJECT:
		/* Read clear the error addresses */
		ramRead= sl_tcram1REG->RAMUERRADDR;
		ramRead= sl_tcram2REG->RAMUERRADDR;
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
		*tcramdataA1 = 0U;
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
		*tcramdataA2 = 0U;

		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
		/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA1 is pointer to volatile data"*/
		/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA1 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		/*SAFETYMCUSW 440 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		eccB1 = (uint64 *)((uint32)tcramdataA1 | 0x00400000u);
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
		/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA2 is pointer to volatile data"*/
		/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA2 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		/*SAFETYMCUSW 440 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		eccB2 = (uint64 *)((uint32)tcramdataA2 | 0x00400000u);

		/* Enable Writes to ECC RAM */
		/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		BIT_SET(sl_tcram1REG->RAMCTRL,TCRAM_RAMCTRL_ECCWREN);
		/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		BIT_SET(sl_tcram2REG->RAMCTRL,TCRAM_RAMCTRL_ECCWREN);

		/* cause a 2-bit ECC error */

		/* Flip 2 bits, this flip in ECC works as 2 bit error when the data part used for ECC is zero*/
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
		*eccB1 ^= TCRAM_SYN_2BIT_DATA_ECC;
		_SL_Barrier_Data_Access();
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
		*eccB2 ^= TCRAM_SYN_2BIT_DATA_ECC;
		_SL_Barrier_Data_Access();
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		ramRead = sl_tcram1REG->RAMCTRL;


		/*flag is set to indicate the current test which is ongoing and
		These flags are used in the sl_esm.c so as to mask the esm callback*/
		if(SRAM_ECC_2BIT_FAULT_INJECT == testType)
		{
			SL_FLAG_SET(SRAM_ECC_2BIT_FAULT_INJECT);
		}
		else
		{
			SL_FLAG_SET(SRAM_ECC_ERROR_FORCING_2BIT);
		}

#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		_SL_Barrier_Data_Access();
		/* Set the self test flag for a self test to indicate the esm handler that this is done as a part of selftest */
		/* read from location with 2-bit ECC error this will cause a data abort to be generated */
		/*SAFETYMCUSW 446 S MR:10.1 <APPROVED> "Needed to generate error"*/
		ramread64 = *tcramdataA1;
		_SL_Barrier_Data_Access();
		/* Restore ctrl registers */
		sl_tcram1REG->RAMCTRL &= ~TCRAM_RAMCTRL_ECCWREN;


	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		ramRead = sl_tcram2REG->RAMCTRL;
		/* Set the self test flag for a self test to indicate the esm handler that this is done as a part of selftest */
		/*SAFETYMCUSW 446 S MR:10.1 <APPROVED> "Needed to generate error"*/
		ramread64 = *tcramdataA2;
		_SL_Barrier_Data_Access();
		/* Restore ctrl registers */
		sl_tcram2REG->RAMCTRL &= ~TCRAM_RAMCTRL_ECCWREN;

		if(SRAM_ECC_ERROR_FORCING_2BIT == testType){
			ram1uerraddr=sl_tcram1REG->RAMUERRADDR;
			ram2uerraddr=sl_tcram2REG->RAMUERRADDR;
			/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
			status functions to get the pass/failure information*/
			/* Check the error status on both banks */
			/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA1 is pointer to volatile data"*/
			/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA1 is pointer to volatile data"*/
			/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA1 is pointer to volatile data"*/
			/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA2 is pointer to volatile data"*/
			/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA2 is pointer to volatile data"*/
			/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataA2 is pointer to volatile data"*/
			if ((((uint32)tcramdataA1 & TCRAM_RAMUERRADDR_UNC_ERROR_ADDR) == ram1uerraddr) &&
					(((uint32)tcramdataA2 & TCRAM_RAMUERRADDR_UNC_ERROR_ADDR) == (ram2uerraddr)) &&
					((1 << ESM_G3ERR_B1TCM_ECC_UNCORR) == (sl_esmREG->SR1[2] & (1u << ESM_G3ERR_B1TCM_ECC_UNCORR)))&&
					((1 << ESM_G3ERR_B0TCM_ECC_UNCORR) == (sl_esmREG->SR1[2] & (1u << ESM_G3ERR_B0TCM_ECC_UNCORR)))) {
				*sram_stResult = ST_PASS;
			} else {
				*sram_stResult = ST_FAIL;
			}
			/* Clear nError */
			_SL_HoldNClear_nError();
			/* Clear the ESM Status */
			sl_esmREG->SR1[2] = ((1u << ESM_G3ERR_B0TCM_ECC_UNCORR) | (1u << ESM_G3ERR_B1TCM_ECC_UNCORR));
			/* Clear double bit error anyways */
			sl_tcram1REG->RAMERRSTATUS |= TCRAM_RAMERRSTATUS_DER;
			sl_tcram2REG->RAMERRSTATUS |= TCRAM_RAMERRSTATUS_DER;
			/* Compute uncorrupted ECC */
			*tcramdataA1 = 0u;
			*tcramdataA2 = 0u;
		}

        /*clear the flags which indicate tests ongoing*/
		if(SRAM_ECC_2BIT_FAULT_INJECT == testType)
		{
		   /*clear the flags which indicate tests ongoing*/
			SL_FLAG_CLEAR(SRAM_ECC_2BIT_FAULT_INJECT);
		}
		else
		{
		   /*clear the flags which indicate tests ongoing*/
			SL_FLAG_CLEAR(SRAM_ECC_ERROR_FORCING_2BIT);
		}
		break;

	case SRAM_ECC_ERROR_FORCING_1BIT:
	case SRAM_ECC_1BIT_FAULT_INJECTION:
	case SRAM_ECC_ERROR_PROFILING:
	case SRAM_ECC_ERROR_PROFILING_FAULT_INJECT:
		/* Read clear the error addresses */
		ramRead= sl_tcram1REG->RAMSERRADDR;
		ramRead= sl_tcram2REG->RAMSERRADDR;

		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		regBkupIntEnaSet = sl_esmREG->IESR1;
		regBckupErrInfulence = sl_esmREG->EEPAPR1;
 		if((SRAM_ECC_ERROR_FORCING_1BIT == testType)||(SRAM_ECC_ERROR_PROFILING == testType)){
 			sl_esmREG->IECR1 = GET_ESM_BIT_NUM(ESM_G1ERR_B0TCM_CORRERR)|
 								GET_ESM_BIT_NUM(ESM_G1ERR_B1TCM_CORRERR);
 			sl_esmREG->DEPAPR1 = GET_ESM_BIT_NUM(ESM_G1ERR_B0TCM_CORRERR)|
 								GET_ESM_BIT_NUM(ESM_G1ERR_B1TCM_CORRERR);

 		}

		*tcramdataB1 = 0U;
		*tcramdataB2 = 0U;
		uint8 testIterations=1u;
		/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB1 is pointer to volatile data"*/
		/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB1 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		/*SAFETYMCUSW 440 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		eccB1 = (uint64 *)((uint32)tcramdataB1 | 0x00400000u);
		/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB2 is pointer to volatile data"*/
		/*SAFETYMCUSW 344 S MR:11.5 "Reason -  FALSE_POSITIVE tcramdataB2 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		/*SAFETYMCUSW 440 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		eccB2 = (uint64 *)((uint32)tcramdataB2 | 0x00400000u);

		/* Enable Writes to ECC RAM */
		/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		BIT_SET(sl_tcram1REG->RAMCTRL,TCRAM_RAMCTRL_ECCWREN);
		/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		BIT_SET(sl_tcram2REG->RAMCTRL,TCRAM_RAMCTRL_ECCWREN);
		regBkupRamTh1 = sl_tcram1REG->RAMTHRESHOLD;
		regBkupRamTh2 = sl_tcram2REG->RAMTHRESHOLD;
		/* Clear RAMOCCUR before setting value */
		sl_tcram1REG->RAMOCCUR=0u;
		sl_tcram2REG->RAMOCCUR=0u;
		if((SRAM_ECC_ERROR_PROFILING_FAULT_INJECT == testType)||(SRAM_ECC_ERROR_PROFILING == testType)){
			sl_tcram1REG->RAMTHRESHOLD = TCRAM_RAMTHRESHOLD_FOR_TEST;
			sl_tcram2REG->RAMTHRESHOLD = TCRAM_RAMTHRESHOLD_FOR_TEST;
			testIterations=(uint8)TCRAM_RAMTHRESHOLD_FOR_TEST;
		}else{
			sl_tcram1REG->RAMTHRESHOLD = 1u;
			sl_tcram2REG->RAMTHRESHOLD = 1u;
			testIterations=1u;
		}

		uint8 iTestCycle=0u;
		*sram_stResult = ST_PASS;
		for(iTestCycle=1u;iTestCycle<=testIterations;iTestCycle++){
			_SL_Barrier_Data_Access();
			/* cause a 1-bit ECC error */
			/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
			*eccB1 ^= TCRAM_SYN_1BIT_DATA_ECC;
			/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL"*/
			*eccB2 ^= TCRAM_SYN_1BIT_DATA_ECC;
		    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
	guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
	This usually means no more than one volatile access occuring in the expression.The recommendation that simple
	assignments should be used is intended to be restricted to simple assignments of the form x = v and not
	"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
	in order to be compliant with the rule. You should implement the rule (the value should be independent of the
	evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
	or you might choose to ignore them." */
			ramRead = sl_tcram1REG->RAMCTRL;
		    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
	guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
	This usually means no more than one volatile access occuring in the expression.The recommendation that simple
	assignments should be used is intended to be restricted to simple assignments of the form x = v and not
	"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
	in order to be compliant with the rule. You should implement the rule (the value should be independent of the
	evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
	or you might choose to ignore them." */
			ramRead = sl_tcram2REG->RAMCTRL;
			/* read from location with to be generate error */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		    _SL_Barrier_Data_Access();
			/*SAFETYMCUSW 446 S MR:10.1 <APPROVED> "Needed to generate error"*/
		    ramread64 = *tcramdataB1;
			/*SAFETYMCUSW 446 S MR:10.1 <APPROVED> "Needed to generate error"*/
		    _SL_Barrier_Data_Access();
		    ramread64 = *tcramdataB2;
			_SL_Barrier_Data_Access();
			if((sl_tcram1REG->RAMOCCUR == (iTestCycle % testIterations))
               && (sl_tcram2REG->RAMOCCUR == (iTestCycle % testIterations))){
				/*Testcase is still in ST_PASS as long as RAMOCCUR gets incremented*/
				*sram_stResult = ST_PASS;
			}else{
				/*Testcase fails if RAMOCCUR does not get incremented*/
				*sram_stResult = ST_FAIL;
                break;
			}
			*tcramdataB1 = 0u;
			*tcramdataB2 = 0u;
		}
		/* If in fault injection mode, this will not clear the status and ESM status */
		if(!((SRAM_ECC_1BIT_FAULT_INJECTION== testType) || (SRAM_ECC_ERROR_PROFILING_FAULT_INJECT == testType))){
			if(ST_FAIL != *sram_stResult){
				/* Check if the single bit errors have been generated for both banks */
				if ((TCRAM_RAMERRSTATUS_ADDR_SERR == (sl_tcram1REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_ADDR_SERR))
						&& ((TCRAM_RAMERRSTATUS_ADDR_SERR == (sl_tcram2REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_ADDR_SERR)))
						&& (((1u << ESM_G1ERR_B0TCM_CORRERR) | (1u << ESM_G1ERR_B1TCM_CORRERR))
								== (sl_esmREG->SR1[0] & ((1u << ESM_G1ERR_B0TCM_CORRERR) | (1u << ESM_G1ERR_B1TCM_CORRERR))))){
					/*LDRA_INSPECTWINDOW 50 */
					/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB1 is pointer to volatile data"*/
					/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB1 is pointer to volatile data"*/
					/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/\
					/*SAFETYMCUSW 408 S MR:12.4 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB1 is pointer to volatile data"*/
					/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB2 is pointer to volatile data"*/
					/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
					if( ((SRAM_ECC_ERROR_FORCING_1BIT==testType) &&
							(sl_tcram1REG->RAMSERRADDR == ((uint32)tcramdataB1 & ((uint32)0x0003FFFFU))) &&
							(sl_tcram2REG->RAMSERRADDR == ((uint32)tcramdataB2 & ((uint32)0x0003FFFFU)))) || (SRAM_ECC_ERROR_PROFILING==testType)) {
						*sram_stResult = ST_PASS;
					}else{
						*sram_stResult = ST_FAIL;
					}
					sl_tcram1REG->RAMOCCUR = 0x00000000u;
					sl_tcram2REG->RAMOCCUR = 0x00000000u;
				} else {
					*sram_stResult = ST_FAIL;
				}
			}
			/* Clear the ESM Status */
			sl_esmREG->SR1[0] = ((1u << ESM_G1ERR_B0TCM_CORRERR) | (1u << ESM_G1ERR_B1TCM_CORRERR));
			/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
			BIT_SET(sl_tcram1REG->RAMERRSTATUS,TCRAM_RAMERRSTATUS_ADDR_SERR);/* Clear for subsequent operation */
			/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
			BIT_SET(sl_tcram2REG->RAMERRSTATUS,TCRAM_RAMERRSTATUS_ADDR_SERR);
			/* Compute uncorrupted ECC */
			*tcramdataB1 = 0u;
			*tcramdataB2 = 0u;
		}
		sl_tcram1REG->RAMTHRESHOLD = regBkupRamTh1;
		sl_tcram2REG->RAMTHRESHOLD = regBkupRamTh2;
		/* Restore ctrl registers */
		sl_tcram1REG->RAMCTRL &= ~TCRAM_RAMCTRL_ECCWREN;
		sl_tcram2REG->RAMCTRL &= ~TCRAM_RAMCTRL_ECCWREN;

		/*Restore grp1 esm interrupt enable*/
		sl_esmREG->IESR1 = regBkupIntEnaSet;
		sl_esmREG->EEPAPR1 = regBckupErrInfulence;
		break;

	case SRAM_PAR_ADDR_CTRL_SELF_TEST:
		/* Once the tests are started, any access to RAM will generate parity errors. So block interrupts */
		irqStatus = _SL_Disable_IRQ();
		/* Should the interrupt routine be backed up and restored before this test is run or
		 * should we use the Shadow register only. Because the ISR reads IOFFHR and IOFFLR
		 * which in turn clears the status register, which will still be there in Shadow register
		 *
		 * Pointing ISR to a dummy ISR which does not read IOFFHR/IOFFLR can resolve this
		 *
		 */

		/* Added for bug fix*/
		tempVal = sl_tcram1REG->RAMPERADDR; /* RAMPERRADDR register must be read for subsequent updates */
		tempVal = sl_tcram2REG->RAMPERADDR;
		tempVal = tempVal; /* avoid compiler warning */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		/* Override parity (actually flip).. NO RAM ACCESS from this point (except intentional errors) */
		/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		sl_tcram1REG->RAMCTRL = (sl_tcram1REG->RAMCTRL & (~TCRAM_RAMCTRL_ADDR_PARITY_OVRRIDE_MASK)) | TCRAM_RAMCTRL_ADDR_PARITY_OVER;
		/* Access any RAM location */
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
		/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB2 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		_SL_Barrier_Data_Access();
		ramread64 = *tcramdataB1; /* Generate read parity error on B0 */
		_SL_Barrier_Data_Access();
    	/* Restore parity, so that we can use the stack */
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		sl_tcram1REG->RAMCTRL = (sl_tcram1REG->RAMCTRL & (~TCRAM_RAMCTRL_ADDR_PARITY_OVRRIDE_MASK));


		/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		sl_tcram2REG->RAMCTRL = (sl_tcram2REG->RAMCTRL & (~TCRAM_RAMCTRL_ADDR_PARITY_OVRRIDE_MASK)) | TCRAM_RAMCTRL_ADDR_PARITY_OVER;
		/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  This can never be NULL as addresss points to an array"*/
		/*SAFETYMCUSW 344 S MR:11.5 <APPROVED> "Reason -  FALSE_POSITIVE tcramdataB2 is pointer to volatile data"*/
		/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
		ramread64 = *tcramdataB2; /* Generate read parity error on B1 */
	    _SL_Barrier_Data_Access();
	    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		sl_tcram2REG->RAMCTRL = (sl_tcram2REG->RAMCTRL & (~TCRAM_RAMCTRL_ADDR_PARITY_OVRRIDE_MASK));


		/* Have to check the Shadow register as the normal ESM status register is cleared during the interrupt handling */
		if ((TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL == (uint32)(sl_tcram1REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL)) &&  /* Read parity error on B1 */
				(TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL == (uint32)(sl_tcram2REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL)) &&  /* Read parity error on B2 */
				(GET_ESM_BIT_NUM(ESM_G2ERR_B0TCM_ADDPAR) == (sl_esmREG->SSR2 & GET_ESM_BIT_NUM(ESM_G2ERR_B0TCM_ADDPAR))) &&   /* B1 Parity error */
				(GET_ESM_BIT_NUM(ESM_G2ERR_B1TCM_ADDPAR) == (sl_esmREG->SSR2 & GET_ESM_BIT_NUM(ESM_G2ERR_B1TCM_ADDPAR)))) {    /* B2 parity error */
			*sram_stResult = ST_PASS;
		} else {
			*sram_stResult = ST_FAIL;
		}
		/* Anyways Clear the interrupt bits */
		sl_esmREG->SSR2 = (1u << ESM_G2ERR_B0TCM_ADDPAR);
		sl_esmREG->SSR2 = (1u << ESM_G2ERR_B1TCM_ADDPAR);
		sl_esmREG->SR1[1] = (1u << ESM_G2ERR_B0TCM_ADDPAR);
		sl_esmREG->SR1[1] = (1u << ESM_G2ERR_B1TCM_ADDPAR);
		sl_tcram1REG->RAMERRSTATUS = TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL;
		sl_tcram2REG->RAMERRSTATUS = TCRAM_RAMERRSTATUS_RADDR_PAR_FAIL;
		tempVal = sl_tcram1REG->RAMPERADDR; /* RAMPERRADDR register must be read for subsequent updates */
		tempVal = sl_tcram2REG->RAMPERADDR;
		tempVal = tempVal; /* avoid compiler warning */

		if (ST_PASS == *sram_stResult) {
			/* Override parity (actually flip).. NO RAM ACCESS from this point (except intentional errors) */
			/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
			sl_tcram1REG->RAMCTRL = (sl_tcram1REG->RAMCTRL & 0xF0FFFFFFU) | TCRAM_RAMCTRL_ADDR_PARITY_OVER;
			/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
			sl_tcram2REG->RAMCTRL = (sl_tcram2REG->RAMCTRL & 0xF0FFFFFFU) | TCRAM_RAMCTRL_ADDR_PARITY_OVER;
			*tcramdataB1 = 0xAAAAAAAABBBBBBBBu; /* Generate write parity error on B1 & B2 */
			*tcramdataB2 = 0xBBBBBBBBAAAAAAAAu;
			/* Restore parity, so that we can use the stack */
		    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
	guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
	This usually means no more than one volatile access occuring in the expression.The recommendation that simple
	assignments should be used is intended to be restricted to simple assignments of the form x = v and not
	"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
	in order to be compliant with the rule. You should implement the rule (the value should be independent of the
	evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
	or you might choose to ignore them." */
			sl_tcram1REG->RAMCTRL = (sl_tcram1REG->RAMCTRL & 0xF0FFFFFFU);
		    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
	guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
	This usually means no more than one volatile access occuring in the expression.The recommendation that simple
	assignments should be used is intended to be restricted to simple assignments of the form x = v and not
	"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
	in order to be compliant with the rule. You should implement the rule (the value should be independent of the
	evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
	or you might choose to ignore them." */
			sl_tcram2REG->RAMCTRL = (sl_tcram2REG->RAMCTRL & 0xF0FFFFFFU);
			if ((TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL == (uint32)(sl_tcram1REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL)) &&  /* Write parity error on B1 */
					(TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL == (uint32)(sl_tcram2REG->RAMERRSTATUS & TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL)) &&  /* Write parity error on B2 */
					(0 != (sl_esmREG->SSR2 & (1u << ESM_G2ERR_B0TCM_ADDPAR))) &&	/* B1 Parity error */
					(0 != (sl_esmREG->SSR2 & (1u << ESM_G2ERR_B1TCM_ADDPAR)))) {    /* B2 parity error */
				*sram_stResult = ST_PASS;
			} else {
				*sram_stResult = ST_FAIL;
			}

			/* Restore parity */
			/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
			sl_tcram1REG->RAMCTRL = (sl_tcram1REG->RAMCTRL & 0xF0FFFFFFU);
			/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
			sl_tcram2REG->RAMCTRL = (sl_tcram2REG->RAMCTRL & 0xF0FFFFFFU);

			/* Anyways Clear the interrupt bits */
			sl_esmREG->SSR2 = (1u << ESM_G2ERR_B0TCM_ADDPAR);
			sl_esmREG->SSR2 = (1u << ESM_G2ERR_B1TCM_ADDPAR);
			sl_esmREG->SR1[1] = (1u << ESM_G2ERR_B0TCM_ADDPAR);
			sl_esmREG->SR1[1] = (1u << ESM_G2ERR_B1TCM_ADDPAR);
			sl_tcram1REG->RAMERRSTATUS = TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL;
			sl_tcram2REG->RAMERRSTATUS = TCRAM_RAMERRSTATUS_WADDR_PAR_FAIL;
			tempVal = sl_tcram1REG->RAMPERADDR; /* RAMPERRADDR register must be read for subsequent updates */
			tempVal = sl_tcram2REG->RAMPERADDR;
			tempVal = tempVal; /* avoid compiler warning */
		}
		_SL_HoldNClear_nError(); /* Clear nError */
		/* Restore interrupts */
		_SL_Restore_IRQ(irqStatus);

		break;

	case SRAM_RADECODE_DIAGNOSTICS:
		retVal = TRUE;
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		/*flag is set to indicate the current test which is ongoing and
		These flags are used in the sl_esm.c so as to mask the esm callback*/
		SL_FLAG_SET(SRAM_RADECODE_DIAGNOSTICS);
		_SL_SelfTest_SRAM_RAD(sl_tcram1REG, sram_stResult);
		_SL_HoldNClear_nError(); /* Clear nError */
		if (ST_PASS == *sram_stResult) {
			sl_esmREG->SR1[1] |= (1u << ESM_G2ERR_B0TCM_UNCORR);
			sl_esmREG->SSR2 |= (1u << ESM_G2ERR_B0TCM_UNCORR);
			/*flag is set to indicate the current test which is ongoing and
		    These flags are used in the sl_esm.c so as to mask the esm callback*/
			SL_FLAG_SET(SRAM_RADECODE_DIAGNOSTICS);
			_SL_SelfTest_SRAM_RAD(sl_tcram2REG, sram_stResult);
			_SL_HoldNClear_nError(); /* Clear nError */
			if (ST_PASS == *sram_stResult) {
				sl_esmREG->SR1[1] |= (1u << ESM_G2ERR_B1TCM_UNCORR);
				sl_esmREG->SSR2 |= (1u << ESM_G2ERR_B1TCM_UNCORR);
			}
		}
		/*clear the flags which indicate tests ongoing*/
		SL_FLAG_CLEAR(SRAM_RADECODE_DIAGNOSTICS);
		break;

	default:
		retVal = FALSE;
		break;
	}
	/* If the test was fault injection and not self test, then do not mask the call back & clear the *
	*  FAULT_INJECTION flag for subsequent runs*/
	if((TRUE) == _sl_fault_injection){
			_sl_fault_injection=FALSE;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  CHECK_RANGE_RAM_PTR is used to check the valid range"*/
	SL_Log_Result(FUNC_ID_ST_SRAM,testType, *sram_stResult , 0U);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
	return(retVal);
}


#define flashBadECC1	0x20000000u
#define flashBadECC2	0x20000008u
/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_Flash (SL_SelfTestType testType, boolean bMode, SL_SelfTest_Result * flash_stResult)
{
	boolean retVal = FALSE;
	uint32 fdiagCtrl = F021F_FDIAGCTRL_DIAG_EN_KEY;
	uint32 regBkupFparOvr, regBckupFdiagctrl, regBkupIntEnaSet, regBckupErrInfulence;
	volatile boolean _sl_fault_injection = FALSE;

	volatile uint32 flashread = 0u;
	/* If fault inject set global variable to flag to the ESM handler that it is a fault injection */
	if((FLASH_ADDRESS_ECC_FAULT_INJECT == testType)||
		(FLASH_ADDRESS_PARITY_FAULT_INJECT == testType)||
		(FLASH_ECC_TEST_MODE_2BIT_FAULT_INJECT == testType)){
		_sl_fault_injection=TRUE;
	}
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	if ((_SELFTEST_FLASHECC_MIN > testType) || (_SELFTEST_FLASHECC_MAX < testType) || !CHECK_RANGE_RAM_PTR(flash_stResult)) {
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_PARAM, 0U);
		return(FALSE);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	/* Error if not in privilege mode */
	if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_ENTRY_CON, 2U);
		return(FALSE);
	}

	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif

	switch(testType) {
	case FLASH_ECC_ADDR_TAG_REG_MODE:
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/* Read to unfreeze the error address registers */
		flashread = sl_flashWREG->FUNCERRADD;
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_ADDR_TAG;
		/* clear flash status flags */
		sl_flashWREG->FEDACSTATUS |= F021F_FEDACSTATUS_ADD_TAG_ERR;
		sl_flashWREG->FDIAGCTRL = fdiagCtrl;
		/* address for test in FRAWDATAL*/
		sl_flashWREG->FRAWDATAL = sl_flashWREG->FPRIMADDTAG;

		sl_flashWREG->FREDUADDTAG^=(uint32)~0;
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;
		_SL_HoldNClear_nError();
		if ((F021F_FEDACSTATUS_ADD_TAG_ERR == (sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_ADD_TAG_ERR)) &&
			(GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR) == (sl_esmREG->SR1[2] & GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR))))
		{
			/*Clear ESM status */
			sl_esmREG->SR1[2]=GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR);
			*flash_stResult = ST_PASS;
			/* clear flash status flags */
			sl_flashWREG->FEDACSTATUS |= F021F_FEDACSTATUS_ADD_TAG_ERR;
			/* Read to unfreeze the error address registers */
			flashread = sl_flashWREG->FUNCERRADD;

			sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
			sl_flashWREG->FDIAGCTRL = fdiagCtrl;
			/*Load primary address tag(with a different value address in FRAW_DATAL != FPRIMADDTAG )*/
			sl_flashWREG->FPRIMADDTAG^=(uint32)~0;
			/*Load duplicate address tag*/
			sl_flashWREG->FRAWDATAL =sl_flashWREG->FREDUADDTAG;
			sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;
			_SL_HoldNClear_nError();
			if ((F021F_FEDACSTATUS_ADD_TAG_ERR == (sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_ADD_TAG_ERR))&&
				(GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR) == (sl_esmREG->SR1[2] & GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR))))
			{
				*flash_stResult = ST_PASS;
			}
			else
			{
				*flash_stResult = ST_FAIL;
			}
		}
		else
		{
			*flash_stResult = ST_FAIL;
			/*if any of the test fails break the loop as the test case has failed*/
		}
		/*Clear ESM status */
		sl_esmREG->SR1[2]=GET_ESM_BIT_NUM(ESM_G3ERR_FMC_UNCORR);
		/* clear flash status flags */
		sl_flashWREG->FEDACSTATUS |= F021F_FEDACSTATUS_ADD_TAG_ERR;
		/* Read to unfreeze the error address registers */
		flashread = sl_flashWREG->FUNCERRADD;
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		retVal = TRUE;
		break;

	case FLASH_ECC_TEST_MODE_1BIT:
		/* Backup parity over ride register */
		regBkupFparOvr = sl_flashWREG->FPAROVR;
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/* Read to unfreeze the error address registers */
		flashread = sl_flashWREG->FCORERRADD;
		sl_flashWREG->FEDACSTATUS= F021F_FEDACSTATUS_ERR_ZERO_FLG;

		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		regBkupIntEnaSet = sl_esmREG->IESR1;
		/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
		regBckupErrInfulence = sl_esmREG->EEPAPR1;
		if((FALSE) == _sl_fault_injection){
			sl_esmREG->IECR1 = GET_ESM_BIT_NUM(ESM_G1ERR_FMC_CORR);
			sl_esmREG->DEPAPR1 = GET_ESM_BIT_NUM(ESM_G1ERR_FMC_CORR);
		}


		/* Setup the diag mode for 1 bit error */
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_TEST_MODE;
		sl_flashWREG->FPAROVR = F021F_FPAROVR_PAR_OVR_ENABLE|F021F_FPAROVR_BUS_PAR_ENABLE;
		sl_flashWREG->FPAROVR |= F021F_FPAROVR_SYN_1BIT_DATA_ECC;
		sl_flashWREG->FDIAGCTRL = fdiagCtrl;
		sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		/*SAFETYMCUSW 58 S MR:14.3 <APPROVED> "Reason -  Needed for the test"*/
		flashread = *(volatile uint32 *)flashBadECC2;


		if ((F021F_FEDACSTATUS_ERR_ZERO_FLG == (sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_ERR_ZERO_FLG))
				&& (sl_flashWREG->FCORERRADD == 0x8u)
				&& ((sl_esmREG->SR1[0] & BIT(ESM_G1ERR_FMC_CORR)) == BIT(ESM_G1ERR_FMC_CORR))) {
			/* Clear flash & ESM status registers */
			sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ERR_ZERO_FLG;
			sl_esmREG->SR1[0] = BIT(ESM_G1ERR_FMC_CORR);
			flashread = sl_flashWREG->FCORERRADD;

			/* Repeat the test for a different address to ensure that the FCORERRADD register is updated correctly */
			/*SAFETYMCUSW 58 S MR:14.3 <APPROVED> "Reason -  Needed for the test"*/
			sl_flashWREG->FDIAGCTRL |= F021F_FDIAGCTRL_DIAG_TRIG;
			flashread = *(volatile uint32 *)flashBadECC1;
			if ((F021F_FEDACSTATUS_ERR_ZERO_FLG == (sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_ERR_ZERO_FLG))
					&& (sl_flashWREG->FCORERRADD == 0x0u)
					&& ((sl_esmREG->SR1[0] & BIT(ESM_G1ERR_FMC_CORR)) == BIT(ESM_G1ERR_FMC_CORR))) {
				*flash_stResult = ST_PASS;
			} else {
				*flash_stResult = ST_FAIL;
			}
		} else {
			*flash_stResult = ST_FAIL;
		}

		/* Anyways clear flash & ESM status registers */
		sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ERR_ZERO_FLG;
		sl_esmREG->SR1[0] = BIT(ESM_G1ERR_FMC_CORR);
		flashread = sl_flashWREG->FCORERRADD;

		/* Clear the diag mode settings */
		sl_flashWREG->FDIAGCTRL &=~(F021F_FDIAGCTRL_DIAGMODE_TEST_MODE|F021F_FDIAGCTRL_DIAG_EN_MASK); /* Clear Diagnostics enable key */
		sl_flashWREG->FPAROVR = regBkupFparOvr;
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;

		/*Restore grp1 esm interrupt enable*/
		sl_esmREG->IESR1 = regBkupIntEnaSet;
		sl_esmREG->EEPAPR1 = regBckupErrInfulence;

		retVal = TRUE; /* Tests were run */
		break;

	case FLASH_ADDRESS_PARITY_SELF_TEST:
	case FLASH_ADDRESS_PARITY_FAULT_INJECT:
		/* Backup registers */
		regBkupFparOvr = sl_flashWREG->FPAROVR;
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/* Read to unfreeze the error address registers */
		flashread = sl_flashWREG->FUNCERRADD;
		sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ADD_PAR_ERR;
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_TEST_MODE;
		sl_flashWREG->FPAROVR = F021F_FPAROVR_PAR_OVR_ENABLE|F021F_FPAROVR_BUS_PAR_ENABLE;
		sl_flashWREG->FDIAGCTRL = fdiagCtrl;
		sl_flashWREG->FPAROVR |= F021F_FPAROVR_ADD_INV_PAR;
		/*flag is set to indicate the current test which is ongoing and
		These flags are used in the sl_esm.c so as to mask the esm callback*/
		if(testType == FLASH_ADDRESS_PARITY_SELF_TEST)
		{
			SL_FLAG_SET(FLASH_ADDRESS_PARITY_SELF_TEST);
		}
		else
		{
			SL_FLAG_SET(FLASH_ADDRESS_PARITY_FAULT_INJECT);
		}
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		flashread = *(volatile uint32 *)flashBadECC1;

		if(FLASH_ADDRESS_PARITY_FAULT_INJECT != testType)
		{
			if ((F021F_FEDACSTATUS_ADD_PAR_ERR==(sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_ADD_PAR_ERR))) {
				sl_flashWREG->FPAROVR = regBkupFparOvr;
				_SL_HoldNClear_nError(); /* Clear nError */
				/* Clear flash & ESM status registers */
				sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ADD_PAR_ERR;
				/*sl_flashWREG->FUNCERRADD = 0x100u;*/
				sl_esmREG->SR1[1] = GET_ESM_BIT_NUM(ESM_G2ERR_FMC_UNCORR);
				flashread = sl_flashWREG->FUNCERRADD;
				*flash_stResult = ST_PASS;
			}else {
				*flash_stResult = ST_FAIL;
			}
			/* Anyways clear flash & ESM status registers */
			sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ADD_PAR_ERR;
			sl_esmREG->SR1[1] =  GET_ESM_BIT_NUM(ESM_G2ERR_FMC_UNCORR);
			sl_esmREG->SSR2 |= GET_ESM_BIT_NUM(ESM_G2ERR_FMC_UNCORR);
			flashread = sl_flashWREG->FUNCERRADD;

			/* Clear the diag mode settings */
			sl_flashWREG->FPAROVR = regBkupFparOvr;
			sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		}
		retVal = TRUE; /* Tests were run */
		/*clear the flags which indicate tests ongoing*/
		if(testType == FLASH_ADDRESS_PARITY_SELF_TEST)
		{
			SL_FLAG_CLEAR(FLASH_ADDRESS_PARITY_SELF_TEST);
		}
		else
		{
			SL_FLAG_CLEAR(FLASH_ADDRESS_PARITY_FAULT_INJECT);
		}
		break;
	case FLASH_ECC_TEST_MODE_2BIT:
	case FLASH_ECC_TEST_MODE_2BIT_FAULT_INJECT:
	case FLASH_ADDRESS_ECC_SELF_TEST:
	case FLASH_ADDRESS_ECC_FAULT_INJECT:
		/* Backup parity over ride register */
		regBkupFparOvr = sl_flashWREG->FPAROVR;
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/* Read to unfreeze the error address registers */
		flashread = sl_flashWREG->FUNCERRADD;
		sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_B1_UNC_ERR;
		sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_ERR_ZERO_FLG;

		/* Setup the diag mode for 2 bit error */
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_TEST_MODE;
		sl_flashWREG->FPAROVR = F021F_FPAROVR_PAR_OVR_ENABLE|F021F_FPAROVR_BUS_PAR_ENABLE;
		if((FLASH_ADDRESS_ECC_SELF_TEST == testType)||(FLASH_ADDRESS_ECC_FAULT_INJECT == testType ))
		{
			sl_flashWREG->FPAROVR |= F021F_FPAROVR_SYN_ADDRESS_ECC;
		}
		else /* FLASH_ECC_TEST_MODE_2BIT || FLASH_ECC_TEST_MODE_2BIT_FAULT_INJECT */
		{
			sl_flashWREG->FPAROVR |= F021F_FPAROVR_SYN_2BIT_DATA_ECC;
		}
		sl_flashWREG->FDIAGCTRL = fdiagCtrl;
		sl_flashWREG->FDIAGCTRL |= F021F_FDIAGCTRL_DIAG_TRIG;
		/*flag is set to indicate the current test which is ongoing and
		These flags are used in the sl_esm.c so as to mask the esm callback*/
		if ((FLASH_ECC_TEST_MODE_2BIT_FAULT_INJECT != testType)&&(FLASH_ADDRESS_ECC_FAULT_INJECT != testType)) {
			SL_FLAG_SET(FLASH_ECC_TEST_MODE_2BIT);
#if FUNCTION_PROFILING_ENABLED
		    SL_Record_Errorcreationtick(testType);
#endif
			/*SAFETYMCUSW 58 S MR:14.3 <APPROVED> "Reason -  Needed for the test"*/
			flashread = *(volatile uint32 *)flashBadECC2;
			if ((F021F_FEDACSTATUS_B1_UNC_ERR==(sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_B1_UNC_ERR))
					&& (sl_flashWREG->FUNCERRADD == 0x8u)
					&& (BIT(ESM_G3ERR_FMC_UNCORR) == (sl_esmREG->SR1[2] & BIT(ESM_G3ERR_FMC_UNCORR)))) {
				_SL_HoldNClear_nError(); /* Clear nError */
				/* Clear flash & ESM status registers */
				sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_B1_UNC_ERR;
				/*sl_flashWREG->FUNCERRADD = 0x100u;*/
				sl_esmREG->SR1[2] = BIT(ESM_G3ERR_FMC_UNCORR);
				flashread = sl_flashWREG->FUNCERRADD;

				/* Repeat the test for a different address to ensure that the FCORERRADD register is updated correctly */
				/*SAFETYMCUSW 58 S MR:14.3 <APPROVED> "Reason -  Needed for the test"*/
				sl_flashWREG->FDIAGCTRL = fdiagCtrl;
				sl_flashWREG->FDIAGCTRL |= F021F_FDIAGCTRL_DIAG_TRIG;
				flashread = *(volatile uint32 *)flashBadECC1;
				if ((F021F_FEDACSTATUS_B1_UNC_ERR == (sl_flashWREG->FEDACSTATUS & F021F_FEDACSTATUS_B1_UNC_ERR))
						&& (sl_flashWREG->FUNCERRADD == 0x0u) && (BIT(ESM_G3ERR_FMC_UNCORR) == (sl_esmREG->SR1[2] & BIT(ESM_G3ERR_FMC_UNCORR)))) {
					_SL_HoldNClear_nError();
					*flash_stResult = ST_PASS;
				} else {
					*flash_stResult = ST_FAIL;
				}
			} else {
				*flash_stResult = ST_FAIL;
			}

			/* Anyways clear flash & ESM status registers */
			sl_flashWREG->FEDACSTATUS = F021F_FEDACSTATUS_B1_UNC_ERR;
			sl_esmREG->SR1[2] =  BIT(ESM_G3ERR_FMC_UNCORR);
			flashread = sl_flashWREG->FUNCERRADD;

			/* Clear the diag mode settings */
			sl_flashWREG->FPAROVR = regBkupFparOvr;
			sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
			/*clear the flags which indicate tests ongoing*/
			SL_FLAG_CLEAR(FLASH_ECC_TEST_MODE_2BIT);
		}
		retVal = TRUE; /* Tests were run */
		break;


	default:
		retVal = FALSE;
		break;
	}
	/* If the test was fault injection and not self test, then do not mask the call back & clear the *
	 *  FAULT_INJECTION flag for subsequent runs*/
	if((TRUE) == _sl_fault_injection){
			_sl_fault_injection=FALSE;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  CHECK_RANGE_RAM_PTR is used to check the valid range"*/
	SL_Log_Result(FUNC_ID_ST_FLASH, testType, *flash_stResult , 0U);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
	return(retVal);
}
#define feeBadECC1		(*(volatile uint32 *)0xF0200000u)
#define feeBadECC2		(*(volatile uint32 *)0xF0200008u)
#define ADDR_DATA_MSW						(0xF0200004u)
#define ADDR_DATA_LSW						(0xF0200000u)
#define FEE_TEST_DATA						0u
#define FEE_ERROR_POS						2u
#define FEE_SYNDROME_BIT2_SINGLE_BIT_ERROR	0xD3u
/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
boolean SL_SelfTest_FEE (SL_SelfTestType testType, boolean bMode, SL_SelfTest_Result * fee_stResult)
{
	boolean retVal = FALSE;
	uint32 fdiagCtrl = F021F_FDIAGCTRL_DIAG_EN_KEY;
	uint32 regBckupFdiagctrl, regBkupIntEnaSet, regBckupErrInfulence;
	uint8 ecc;
	uint8 syndrome=0U;
	volatile boolean _sl_fault_injection = FALSE;
	volatile uint32 flashread = 0u;

#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
	/* If fault inject set global variable to flag to the ESM handler that it is a fault injection */
	if((FEE_ECC_TEST_MODE_1BIT_FAULT_INJECT == testType)||
		(FEE_ECC_TEST_MODE_2BIT_FAULT_INJECT == testType)){
		_sl_fault_injection=TRUE;
	}
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	if ((_SELFTEST_FEEECC_MIN > testType) || (_SELFTEST_FEEECC_MAX < testType) || !CHECK_RANGE_RAM_PTR(fee_stResult)) {
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_PARAM, 0U);
		return(FALSE);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	/* Error if not in privilege mode */
	if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_ENTRY_CON, 2U);
		return(FALSE);
	}

	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_FLASH, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif
	switch(testType) {

	case FEE_ECC_DATA_CORR_MODE:
	case FEE_ECC_TEST_MODE_1BIT:
	case FEE_ECC_TEST_MODE_1BIT_FAULT_INJECT:
	case FEE_ECC_TEST_MODE_2BIT:
	case FEE_ECC_TEST_MODE_2BIT_FAULT_INJECT:
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_DATA_CORR;
		/*  Clear all the status errors*/
		sl_flashWREG->EESTATUS |= ~0;
		/* Clear this to unfree error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;
		flashread=sl_flashWREG->EECORRERRADD;

		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
		regBkupIntEnaSet = sl_esmREG->IESR4;
		regBckupErrInfulence = sl_esmREG->IEPSR4;
		if((FALSE) == _sl_fault_injection){
			sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_CORRERR)|GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
			sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_CORRERR)|GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
		}

		/* Load FEMU_XX regs in order to generate ecc */
		sl_flashWREG->FEMUADDR=ADDR_DATA_MSW;
		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		sl_flashWREG->FEMUDLSW = FEE_TEST_DATA;

		/*ecc for the correct data*/
		ecc = sl_flashWREG->FEMUECC;
		/* Load corrupt data in FEMU_XXX regs single bit error */
		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		/* Flip a bit and generate single bit error*/
		if((FEE_ECC_TEST_MODE_2BIT_FAULT_INJECT == testType) || (FEE_ECC_TEST_MODE_2BIT == testType)){
			sl_flashWREG->FEMUDLSW = FEE_TEST_DATA ^ (0x3U<<(FEE_ERROR_POS));
		}else{
			sl_flashWREG->FEMUDLSW = FEE_TEST_DATA ^ BIT(FEE_ERROR_POS);
		}

		/* Set SECDED mode as fee as only fee is supported for this mode
		 * and enable the Diagnosis*/
		sl_flashWREG->FDIAGCTRL = fdiagCtrl|F021F_FDIAGCTRL_DIAGECCSEL_FEE;
		sl_flashWREG->FEMUECC = ecc;
		/* Trigger the test */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;

		if((FEE_ECC_DATA_CORR_MODE == testType) || (FEE_ECC_TEST_MODE_1BIT == testType)){
			/* Check the error flags, if single bit error and only one of ERR_ONE_FLG or ERR_ZERO_FLG is set */
			if((F021F_EE_STATUS_D_CORR_ERR_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_D_CORR_ERR_FLG)) &&
					(GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_CORRERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_CORRERR))) &&
					(((F021F_EE_STATUS_ERR_ZERO_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_ERR_ZERO_FLG))	&&
						(!(F021F_EE_STATUS_ERR_ONE_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_ERR_ONE_FLG))))
						||
						((!(F021F_EE_STATUS_ERR_ZERO_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_ERR_ZERO_FLG)))	&&
								(F021F_EE_STATUS_ERR_ONE_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_ERR_ONE_FLG)))) &&
										(FEE_ERROR_POS == (sl_flashWREG->EECORRERRPOS & F021F_EECORRERRPOS_MASK))){
					*fee_stResult = ST_PASS;
				}
			else{
				*fee_stResult = ST_FAIL;
			}
			/*Clear the status set during the test*/
			sl_flashWREG->EESTATUS |= F021F_EE_STATUS_D_CORR_ERR_FLG|
									F021F_EE_STATUS_ERR_ZERO_FLG|
									F021F_EE_STATUS_ERR_ONE_FLG;
			sl_esmREG->SR4[0] = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_CORRERR);
		}
		else if(FEE_ECC_TEST_MODE_2BIT == testType){
			if((F021F_EE_STATUS_D_UNC_ERR_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_D_UNC_ERR_FLG)) &&
					((F021F_EE_STATUS_UNC_ERR_FLG == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_UNC_ERR_FLG)))
					&& (sl_flashWREG->EEUNCERRADD == (ADDR_DATA_MSW & F021F_EEUNCERRADD_MASK))
					&& (GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR)))){
				*fee_stResult = ST_PASS;
				/*Clear the status set during the test*/
				sl_flashWREG->EESTATUS |= F021F_EE_STATUS_D_UNC_ERR_FLG|
										F021F_EE_STATUS_UNC_ERR_FLG;
				sl_esmREG->SR4[0] = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
			}
			else{
				*fee_stResult = ST_FAIL;
			}
		}
		else
		{
			*fee_stResult = ST_FAIL;
		}
		retVal = TRUE;
		/* Clear the diag mode settings */
		sl_flashWREG->FDIAGCTRL &=~(F021F_FDIAGCTRL_DIAGMODE_DATA_CORR|F021F_FDIAGCTRL_DIAG_EN_MASK); /* Clear Diagnostics enable key */
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		/* Read and unfreeze error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;
		flashread=sl_flashWREG->EECORRERRADD;

		/*Restore grp1 esm interrupt enable*/
		sl_esmREG->IESR4 = regBkupIntEnaSet;
		sl_esmREG->IEPSR4 = regBckupErrInfulence;
		break;

	case FEE_ECC_SYN_REPORT_MODE:
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/*  Clear all the status errors*/
		sl_flashWREG->EESTATUS |= ~0;
		/* Clear this to unfree error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;
		/*load FEMU_XX regs in order to generate ecc and use it for next operations*/
		sl_flashWREG->FEMUADDR=ADDR_DATA_MSW;
		fdiagCtrl |= F021F_FDIAGCTRL_DIAGMODE_SYN_RPT;
		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		sl_flashWREG->FEMUDLSW = FEE_TEST_DATA;
		/* Store ECC*/
		ecc = sl_flashWREG->FEMUECC;

		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		sl_flashWREG->FEMUDLSW = FEE_TEST_DATA ^ BIT(FEE_ERROR_POS);
		/* Calculate the Syndrome value */
		syndrome = ecc ^ sl_flashWREG->FEMUECC;

		/* Set the data back to the original data */
		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		sl_flashWREG->FEMUDLSW = FEE_TEST_DATA;
		/* Set the FDIAGCTRL register*/
		/* Set SECDED mode as fee as only fee is supported for this mode */
		sl_flashWREG->FDIAGCTRL = fdiagCtrl|F021F_FDIAGCTRL_DIAGECCSEL_FEE;
		/* Introduce the single bit error corresponding to the calculated syndrome */
		sl_flashWREG->FEMUDMSW = FEE_TEST_DATA;
		sl_flashWREG->FEMUDLSW = FEE_TEST_DATA ^ BIT(FEE_ERROR_POS);
		/* Trigger the diagnosis */
		sl_flashWREG->FDIAGCTRL |=(F021F_FDIAGCTRL_DIAG_TRIG);
		/* Now the FEMUECC would contain the actual syndrome, as the mode is FLASH_ECC_SYN_REPORT_MODE
		 * Check this value to the calculated syndrome, if it is match the diagnosis passes */
		if((syndrome) == sl_flashWREG->FEMUECC){
			*fee_stResult = ST_PASS;
		}
		else
		{
			*fee_stResult = ST_FAIL;
		}
		/* Clear the diag mode settings */
		sl_flashWREG->FDIAGCTRL &=~(F021F_FDIAGCTRL_DIAGMODE_DATA_CORR|F021F_FDIAGCTRL_DIAG_EN_MASK); /* Clear Diagnostics enable key */
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		/*Clear the status set during the test*/
		sl_flashWREG->EESTATUS |= ~0;
		retVal = TRUE;
		/* Read and unfreeze error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;
		break;

	case FEE_ECC_MALFUNCTION_MODE1:
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		/* Clear this to unfree error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;

		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
		regBkupIntEnaSet = sl_esmREG->IESR4;
		regBckupErrInfulence = sl_esmREG->IEPSR4;
		if((FALSE) == _sl_fault_injection){
			sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
			sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
		}

		/* Set diagmode and SECDED mode as fee as only fee is supported for this mode */
		fdiagCtrl |= F021F_FDIAGCTRL_DMODE_MALFUNC1|F021F_FDIAGCTRL_DIAGECCSEL_FEE;
		/*  Clear all the status errors*/
		sl_flashWREG->EESTATUS |= (uint32)~0;

		/* Enable EDACMODE and put a non zero value is FRAWECC*/
		sl_flashWREG->FDIAGCTRL = fdiagCtrl;
		sl_flashWREG->FRAWECC = 1U;
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		/* Trigger the test */
		sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;
		/* Check error */
		if((F021F_EE_STATUS_CME == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_CME))&&
			(GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR)))){
			*fee_stResult = ST_PASS;
		}
		else
		{
			*fee_stResult = ST_FAIL;
		}
		/* Clear ESM bits */
		sl_esmREG->SR4[0] = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
		/* Clear the diag mode settings */
		sl_flashWREG->FDIAGCTRL &=~(F021F_FDIAGCTRL_DIAGMODE_DATA_CORR|F021F_FDIAGCTRL_DIAG_EN_MASK); /* Clear Diagnostics enable key */
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		/*Clear the status set during the test*/
		sl_flashWREG->EESTATUS |= ~0;
		retVal = TRUE;
		/* Read and unfreeze error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;

		/*Restore grp1 esm interrupt enable*/
		sl_esmREG->IESR4 = regBkupIntEnaSet;
		sl_esmREG->IEPSR4 = regBckupErrInfulence;
		break;

	case FEE_ECC_MALFUNCTION_MODE2:
		regBckupFdiagctrl = sl_flashWREG->FDIAGCTRL;
		sl_flashWREG->FDIAGCTRL=0U;
		/* Read and unfreeze error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;

		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
		regBkupIntEnaSet = sl_esmREG->IESR4;
		regBckupErrInfulence = sl_esmREG->IEPSR4;
		if((FALSE) == _sl_fault_injection){
			sl_esmREG->IECR4= GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
			sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
		}

		/* Set diagmode and SECDED mode as fee as only fee is supported for this mode */
		sl_flashWREG->FDIAGCTRL|= F021F_FDIAGCTRL_DIAGECCSEL_FEE;
		sl_flashWREG->FDIAGCTRL|= F021F_FDIAGCTRL_DMODE_MALFUNC2;

		/*  Clear all the status errors*/
		sl_flashWREG->EESTATUS |= ~0;

		/* Enable EDACMODE*/
		/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
		BIT_SET(sl_flashWREG->FDIAGCTRL,F021F_FDIAGCTRL_DIAG_EN_KEY);
		/* Invert data for the ecc calculation and put zero in FRAWECC */
		sl_flashWREG->FRAWDATAH = ~sl_flashWREG->FRAWDATAH;
		sl_flashWREG->FRAWDATAL = ~sl_flashWREG->FRAWDATAL;
		sl_flashWREG->FRAWECC = 0U;
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		/* Trigger the test */
		sl_flashWREG->FDIAGCTRL |=F021F_FDIAGCTRL_DIAG_TRIG;

		/* Check Error */
		if((F021F_EE_STATUS_CME == (sl_flashWREG->EESTATUS & F021F_EE_STATUS_CME))&&
				(GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR)))){
			*fee_stResult = ST_PASS;
		}
		else
		{
			*fee_stResult = ST_FAIL;
		}
		/* Clear ESM bits */
		sl_esmREG->SR4[0] = GET_ESM_BIT_NUM(ESM_G1ERR_EEPROM_UNCORRERR);
		/* Clear the diag mode settings */
		sl_flashWREG->FDIAGCTRL &=~(F021F_FDIAGCTRL_DIAGMODE_DATA_CORR|F021F_FDIAGCTRL_DIAG_EN_MASK); /* Clear Diagnostics enable key */
		sl_flashWREG->FDIAGCTRL = regBckupFdiagctrl;
		/*Clear the status set during the test*/
		sl_flashWREG->EESTATUS |= ~0;
		retVal = TRUE;
		/* Read and unfreeze error reporting */
		flashread=sl_flashWREG->EEUNCERRADD;
		/*Restore grp1 esm interrupt enable*/
		sl_esmREG->IESR4 = regBkupIntEnaSet;
		sl_esmREG->IEPSR4 = regBckupErrInfulence;
		break;
	default:
		retVal = FALSE;
		break;
	}
	/* If the test was fault injection and not self test, then do not mask the call back & clear the *
	 *  FAULT_INJECTION flag for subsequent runs*/
	if((TRUE) == _sl_fault_injection){
			_sl_fault_injection=FALSE;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	/*SAFETYMCUSW 45 D MR:21.1 <APPROVED> "Reason -  CHECK_RANGE_RAM_PTR is used to check the valid range"*/
	SL_Log_Result(FUNC_ID_ST_FLASH, testType, *fee_stResult , 0U);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
	return(retVal);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
/*SAFETYMCUSW 62 D MR: 16.7 <APPROVED> "changes may be made in the usage of the testType" */
boolean SL_SelfTest_PBIST (register SL_SelfTestType testType, register uint32 ramGroup, register uint32 algoInfo)
{
    register uint32 tempVal;
    register boolean retVal = FALSE;

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	if (0 != sl_pbistREG->PACT)
	{
		SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_ENTRY_CON, 1u);
		retVal = FALSE;
		return retVal;
	}

    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_ENTRY_CON, 0u);
        retVal =  FALSE;
        return retVal;
    }

	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_ENTRY_CON, 2u);
		return(FALSE);
    }
#endif

#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/*SAFETYMCUSW 437 S MR: 17.3 <APPROVED> "Reason - FALSE POSITIVE _SELFTEST_PBIST_MIN
	  * and testType are object pointers of same type*/
    if ((_SELFTEST_PBIST_MIN > testType) || (_SELFTEST_PBIST_MAX < testType)) {
        SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_PARAM, 0u);
        retVal = FALSE;
        return retVal;
    }
    if (ALL_PBIST_RAM_GROUPS != (ALL_PBIST_RAM_GROUPS | ramGroup)) {
        SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_PARAM, 1u);
        retVal = FALSE;
        return retVal;
    }
    if (ALL_PBISALGO != (ALL_PBISALGO | algoInfo)) {
        SL_Log_Error(FUNC_ID_ST_PBIST, ERR_TYPE_PARAM, 2u);
        retVal = FALSE;
        return retVal;
    }
#endif
    switch(testType) {
        case PBIST_EXECUTE:
        case PBIST_EXECUTE_OVERRIDE:
            /* PBIST ROM clock frequency = HCLK frequency /2 */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            /*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
            BF_SET(sl_systemREG1->MSTGCR,ROM_CLK_SRC_HCKL_DIV_2,BF_ROM_DIV_START,BF_ROM_DIV_LENGTH);
            /* Enable PBIST controller */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            sl_systemREG1->MSINENA = SYSREG1_MSINENA_MSIENA;
            /* Enable PBIST Contrlller */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            /*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
            BF_SET(sl_systemREG1->MSTGCR,ENABLE_MEM_STEST_CTRL,BF_MSTGENA_START,BF_MSTGENA_LENGTH);
            /* Wait for 32 VBUS Clocks */
            for (tempVal=0u; tempVal<(VBUS_CLK_CYCLES + (VBUS_CLK_CYCLES * 1u)); tempVal++)
            {

            }
            /* Enable PBIST clocks and ROM clock */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            sl_pbistREG->PACT = (PBIST_PACT_PACT1 | PBIST_PACT_PACT0);
            /* Select the algorithms */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            sl_pbistREG->ALGO = algoInfo;
            if (PBIST_EXECUTE_OVERRIDE == testType) {
                /* Override RINFOx with ROM contents */
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
                sl_pbistREG->OVER = ENABLE_OVERRIDE;
            }
            else {
                /* Select RAM groups */
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
                sl_pbistREG->RINFOL = ramGroup;
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
                sl_pbistREG->RINFOU = 0x00000000u; /* No RAM group between 33-64 */
                /* Do not override RINFOx with ROM contents */
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	         	sl_pbistREG->OVER = DISABLE_OVERRIDE;
            }
            /* Algorithm code is loaded from ROM */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            sl_pbistREG->ROM = ALG_RAM_FROM_ROM;
            /* Start PBIST */
            /* Note: If executing on TCM RAM, Stack Contents are corrupted, so be careful with return data */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            sl_pbistREG->DLR = (PBIST_DLR_DLR4 | PBIST_DLR_DLR2);
            retVal = TRUE;
         break;
        default:
            break;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
    SL_Log_Result(FUNC_ID_ST_PBIST, testType, (SL_SelfTest_Result)retVal , 0u);
#endif
    return(retVal);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_Status_PBIST(SL_PBIST_FailInfo *param1)
{
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    if (FALSE == CHECK_RANGE_RAM_PTR(param1)) {
        SL_Log_Error(FUNC_ID_ST_PBIST_STATUS, ERR_TYPE_PARAM, 0u);
        return FALSE;
    }
#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_PBIST_STATUS, ERR_TYPE_ENTRY_CON, 0u);
        return FALSE;
    }
#endif
        /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
        if ((sl_systemREG1->MSTCGSTAT & 0x1u) == 0x0u)
        {
           return FALSE;
        }
        else
        {
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
			if ((sl_pbistREG->FSRF0 == 0u) && (sl_pbistREG->FSRF1 == 0u)) {
				/* Return PASS*/
				param1->stResult 			= ST_PASS;
				param1->port0FailCount 		= 0u;
				param1->port1FailCount 		= 0u;
				param1->port0FailAddress    = 0u;
				param1->port1FailAddress    = 0u;
				param1->port0FailData       = 0u;
				param1->port1FailData       = 0u;
			} else {
				/* Store the failure data in OUT params */
				param1->stResult			= ST_FAIL;
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				/*SAFETYMCUSW 439 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port0FailCount      = (uint8) (sl_pbistREG->FSRC0 & 0xFFu);
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port1FailCount      = (uint8) (sl_pbistREG->FSRC1 & 0xFFu);
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port0FailAddress    = (uint16) (sl_pbistREG->FSRA0 & 0xFFFFu);
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port1FailAddress    = (uint16) (sl_pbistREG->FSRA0 & 0xFFFFu);
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port0FailData       = sl_pbistREG->FSRDL0;
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
				param1->port1FailData       = sl_pbistREG->FSRDL1;
			}
		/* Stop the PBIST */
		SL_SelfTest_PBIST_StopExec();
#if(FUNC_RESULT_LOG_ENABLED == 1)
		/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
		SL_Log_Result(FUNC_ID_ST_PBIST_STATUS, (SL_SelfTestType)0, param1->stResult, 0u);
#endif
        }
    return TRUE;
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
boolean SL_SelfTest_WaitCompletion_PBIST(void)
{
	register boolean retVal = FALSE;
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	if ((sl_systemREG1->MSTCGSTAT & 0x1u) == 0x1u) {
	    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
		sl_systemREG1->MSTCGSTAT = 0x1u;
		retVal = TRUE;
	} else {
		retVal = FALSE;
	}
	return retVal;
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
boolean SL_SelfTest_PBIST_StopExec(void)
{
	/* Stop the PBIST */
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	sl_pbistREG->PACT = 0x0u;
	/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	/*SAFETYMCUSW 9 S MR: 12.2 <APPROVED> "Assignment in an expression is valid here" */
	BF_SET(sl_systemREG1->MSTGCR,DISABLE_MEM_STEST_CTRL,BF_MINITGENA_START,BF_MINITGENA_LENGTH);
	return(TRUE);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_STC(register SL_SelfTestType testType, register boolean bMode, register SL_STC_Config* config)
{
	register uint32 tempVal = 0U;
    boolean retval = FALSE;

#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	/*LDRA_INSPECTWINDOW 50 */
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 437 S MR: 17.3 <APPROVED> "Reason - FALSE POSITIVE _SELFTEST_PBIST_MIN
	  * and testType are object pointers of same type*/
	if ((_SELFTEST_STC_MIN > testType) || (_SELFTEST_STC_MAX < testType)||
			!CHECK_RANGE_RAM_PTR(config)) {
		SL_Log_Error(FUNC_ID_ST_STC, ERR_TYPE_PARAM, 0U);
		retval = FALSE;
		return(retval);
	}
	/* Error if interval count is greater than 24 */
	if(config->intervalCount>STC_MAX_INTERVALS){
		SL_Log_Error(FUNC_ID_ST_STC, ERR_TYPE_PARAM, 0U);
        retval = FALSE;
		return(retval);
	}
	if(config->stcClockDiv>STC_MAX_CLOCK_DIV){
		SL_Log_Error(FUNC_ID_ST_STC, ERR_TYPE_PARAM, 0U);
        retval = FALSE;
		return(retval);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	/* Error if not in privilege mode */
		if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
			SL_Log_Error(FUNC_ID_ST_STC, ERR_TYPE_ENTRY_CON, 2U);
	        retval = FALSE;
			return(retval);
	}

	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_STC, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif

	/* Configure the clock divider */
	sl_systemREG2->STCCLKDIV |= ((config->stcClockDiv & 0x07u) << 24);

	/* Configure the interval count & restart/continue */
	tempVal = 0U;
	tempVal |= ((uint32)config->intervalCount << STC_STCGCR0_INTCOUNT_START);
	if (TRUE == config->restartInterval0) {
		tempVal |= STC_STCGCR0_RS_CNT;
	}
	sl_stcREG->STCGCR0 = tempVal;

	/* If in compare selfcheck (fault injection) mode then setup STCSCSCR */
	if (STC_COMPARE_SELFCHECK == testType) {
		sl_stcREG->STCSCSCR = (uint32)(STC_STCSCSCR_FAULT_INS|STC_STCSCSCR_SELF_CHECK_KEY);
	}

	/* Setup the timeout value */
	sl_stcREG->STCTPR = config->timeoutCounter;

	/* Enable STC run */
	sl_stcREG->STCGCR1 = STC_STCGCR1_STC_ENA;
	for (tempVal=0u; tempVal<32u; tempVal++) {
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	/* The system goes into reset after the test, and the result of the test has to be found out from there
	 * Now logging the value of result as 0xEF which denotes 'do not know'state
	 */
    SL_Log_Result(FUNC_ID_ST_STC,testType, (SL_SelfTest_Result)0xEFU , 0u);
#endif
	/* Kick off the STC execution */
	_SL_Kickoff_STC_execution();


	/* Execution never comes here !!! */
	retval = TRUE;
	return (retval);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
boolean SL_SelfTest_Status_STC (SL_STC_FailInfo * failInfostc)
{
	boolean retVal = FALSE;

	if (STC_STCGSTAT_TEST_DONE == (STC_STCGSTAT_TEST_DONE & sl_stcREG->STCGSTAT)) {
		retVal = TRUE;/* Test was completed */

		/* Get test results */
		if (STC_STCGSTAT_TEST_FAIL == (STC_STCGSTAT_TEST_FAIL & sl_stcREG->STCGSTAT)) {
			/* Test completed & failed */
			failInfostc->stResult = ST_FAIL;
			/* Clear the error */
			sl_stcREG->STCGSTAT = STC_STCGSTAT_TEST_FAIL;
		} else {
			/* Test completed & passed */
			failInfostc->stResult = ST_PASS;
		}

		if (STC_STCFSTAT_CPU1_FAIL == (STC_STCFSTAT_CPU1_FAIL & sl_stcREG->STCFSTAT)) {
			sl_stcREG->STCFSTAT = STC_STCFSTAT_CPU1_FAIL;
			failInfostc->CPU1Failure = ST_PASS;
		} else {
			failInfostc->CPU1Failure = ST_FAIL;
		}

		if (STC_STCFSTAT_CPU2_FAIL == (STC_STCFSTAT_CPU2_FAIL & sl_stcREG->STCFSTAT)) {
			sl_stcREG->STCFSTAT = STC_STCFSTAT_CPU2_FAIL;
			failInfostc->CPU2Failure = ST_PASS;
		} else {
			failInfostc->CPU2Failure = ST_FAIL;
		}

		if (STC_STCFSTAT_TO_ERR == (STC_STCFSTAT_TO_ERR & sl_stcREG->STCFSTAT)) {
			sl_stcREG->STCFSTAT = STC_STCFSTAT_TO_ERR;
			failInfostc->TimeOutFailure = ST_PASS;
		} else {
			failInfostc->TimeOutFailure = ST_FAIL;
		}
	} else {
		/* Test did not complete */
		retVal = FALSE;
	}

	return(retVal);
}


/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
#if defined(_TMS570LS31x_) || defined(_TMS570LS12x_) || defined(_RM48x_) || defined(_RM46x_)
boolean SL_SelfTest_PSCON(SL_SelfTestType testType, boolean mode, SL_PSCON_FailInfo * param1)
{
	register boolean retVal = TRUE;
	register uint32 regBkupIntEnaSet, regBckupErrInfulence;
	uint32 regbackup;

#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	if ((_SELFTEST_PSCON_MIN > testType) || (_SELFTEST_PSCON_MAX < testType) || !CHECK_RANGE_RAM_PTR(param1)) {
		SL_Log_Error(FUNC_ID_ST_PSCON, ERR_TYPE_PARAM, 0U);
			return(FALSE);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	/* Error if not in privilege mode */
	if ((PSCON_PMA_TEST != testType) && (ARM_MODE_USR == _SL_Get_ARM_Mode())) {
		SL_Log_Error(FUNC_ID_ST_PSCON, ERR_TYPE_ENTRY_CON, 2U);
		return(FALSE);
	}
	if ((PSCON_PMA_TEST == testType) && (ARM_MODE_USR != _SL_Get_ARM_Mode())) {
			SL_Log_Error(FUNC_ID_ST_PSCON, ERR_TYPE_ENTRY_CON, 2U);
			return(FALSE);
	}


	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_PSCON, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
	retVal = TRUE;
	switch(testType) {
		case PSCON_SELF_TEST:
			/*flag is set to indicate the current test which is ongoing and
		    These flags are used in the sl_esm.c so as to mask the esm callback*/  
			SL_FLAG_SET(PSCON_SELF_TEST);
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_SELF_TEST_MODE;
			if ((TRUE) == mode) {
				/* Wait for the self-test to complete & get results*/
			    /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
				while (TRUE != SL_SelfTest_Status_PSCON(param1)) {
				}
			}
			break;

		case PSCON_ERROR_FORCING:
		case PSCON_ERROR_FORCING_FAULT_INJECT:
			/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
			regBkupIntEnaSet = sl_esmREG->IESR4;
			regBckupErrInfulence = sl_esmREG->IEPSR4;
			if(PSCON_ERROR_FORCING == testType){
		    	/*flag is set to indicate the current test which is ongoing and
		       These flags are used in the sl_esm.c so as to mask the esm callback*/
				SL_FLAG_SET(PSCON_ERROR_FORCING);
				sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_COMPARE_ERR);
				sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_COMPARE_ERR);
				sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
				sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
			}
			else
			{
			    /*flag is set to indicate the current test which is ongoing and
		        These flags are used in the sl_esm.c so as to mask the esm callback*/
				SL_FLAG_SET(PSCON_ERROR_FORCING_FAULT_INJECT);
			}
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_ERROR_FORCING_MODE;
			if(PSCON_ERROR_FORCING == testType)
			{
				if (GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_COMPARE_ERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_COMPARE_ERR))) {
					sl_esmREG->SR4[0] |= GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_COMPARE_ERR);
					sl_esmREG->SR4[0] |= GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
					param1->stResult = ST_PASS;
				} else {
					param1->stResult = ST_FAIL;
				}
				/*clear the flags which indicate tests ongoing*/
				SL_FLAG_CLEAR(PSCON_ERROR_FORCING);
			}
			else
			{
			/*clear the flags which indicate tests ongoing*/
				SL_FLAG_CLEAR(PSCON_ERROR_FORCING_FAULT_INJECT);
			}
			/*Restore grp1 esm interrupt enable*/
			sl_esmREG->IESR4 = regBkupIntEnaSet;
			sl_esmREG->IEPSR4 = regBckupErrInfulence;
			/* Revert to normal operation */
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_LOCKSTEP_MODE;
			break;

		case PSCON_SELF_TEST_ERROR_FORCING:
		case PSCON_SELF_TEST_ERROR_FORCING_FAULT_INJECT:
			/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
	     	/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
	    	status functions to get the pass/failure information*/		
			regBkupIntEnaSet = sl_esmREG->IESR4;
			regBckupErrInfulence = sl_esmREG->IEPSR4;
			if(PSCON_SELF_TEST_ERROR_FORCING ==  testType){
				/*flag is set to indicate the current test which is ongoing and
			    These flags are used in the sl_esm.c so as to mask the esm callback*/
				SL_FLAG_SET(PSCON_SELF_TEST_ERROR_FORCING);
				sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
				sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
			}
			else
			{
		    	/*flag is set to indicate the current test which is ongoing and
	        	These flags are used in the sl_esm.c so as to mask the esm callback*/ 
				SL_FLAG_SET(PSCON_SELF_TEST_ERROR_FORCING_FAULT_INJECT);
			}
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_ST_ERROR_FORCING_MODE;
			if(PSCON_SELF_TEST_ERROR_FORCING == testType)
			{
				if (GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR) == (sl_esmREG->SR4[0] & GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR))) {
					sl_esmREG->SR4[0] |= GET_ESM_BIT_NUM(ESM_G1ERR_PSCON_SELTEST_ERR);
					param1->stResult = ST_PASS;
				} else {
					param1->stResult = ST_FAIL;
				}
				/*clear the flags which indicate tests ongoing*/
				SL_FLAG_CLEAR(PSCON_SELF_TEST_ERROR_FORCING);
			}
			else
			{
			/*clear the flags which indicate tests ongoing*/
				SL_FLAG_CLEAR(PSCON_SELF_TEST_ERROR_FORCING_FAULT_INJECT);
			}
			/*Restore grp1 esm interrupt enable*/
			sl_esmREG->IESR4 = regBkupIntEnaSet;
			sl_esmREG->IEPSR4 = regBckupErrInfulence;
			/* Revert to normal operation */
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_LOCKSTEP_MODE;
			break;

		case PSCON_PMA_TEST:
			/* Make sure we are in non-privilege (user) mode */
			if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
				retVal = TRUE;
				regbackup = sl_pmmREG->PRCKEYREG;
				/*flag is set to indicate the current test which is ongoing and
		        These flags are used in the sl_esm.c so as to mask the esm callback*/
				SL_FLAG_SET(PSCON_PMA_TEST);
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
				/* Try writing to GLOBALCTRL1.AUTO_CLK_WAKE_ENA, which should result in an abort*/
				sl_pmmREG->PRCKEYREG = 0x0000000FU;
				if(regbackup == sl_pmmREG->PRCKEYREG)
				{
					param1->stResult = ST_PASS;
				}
				else
				{
					param1->stResult = ST_FAIL;
				}
			} else {
				/* Error, must be in user mode to run this test */
				retVal = FALSE;
			}
			/*clear the flags which indicate tests ongoing*/
			SL_FLAG_CLEAR(PSCON_PMA_TEST);
			/* Revert to normal operation */
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_LOCKSTEP_MODE;
			break;

		default:
			/* Revert to normal operation */
			sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_LOCKSTEP_MODE;
			break;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	SL_Log_Result(FUNC_ID_ST_PSCON, testType, param1->stResult , 0U);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
	return(retVal);
}
#endif

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
#if defined(_TMS570LS31x_) || defined(_TMS570LS12x_) || defined(_RM48x_) || defined(_RM46x_)
boolean SL_SelfTest_Status_PSCON (SL_PSCON_FailInfo * param1)
{
	boolean retVal = FALSE;
	if ((PMM_PSCON_LPDDCSTAT1_LSTC != ((uint32)(PMM_PSCON_LPDDCSTAT1_LSTC & sl_pmmREG->LPDDCSTAT1))) &&
			(PMM_PSCON_MPDDCSTAT1_MSTC != ((uint32)(PMM_PSCON_MPDDCSTAT1_MSTC & sl_pmmREG->MPDDCSTAT1)))){
		retVal = FALSE;
	} else {
		/* If one of the Power or Memory domains have failed, mark the ST as failure */
		if  ((0u == (PMM_PSCON_LPDDCSTAT2_LSTE & sl_pmmREG->LPDDCSTAT2)) &&
				(0u == (PMM_PSCON_MPDDCSTAT2_MSTE & sl_pmmREG->MPDDCSTAT2))) {
			param1->stResult = ST_PASS;
		} else {
			param1->stResult = ST_FAIL;
		}

		param1->pdFailure = sl_pmmREG->LPDDCSTAT2;
		param1->mdFailure = sl_pmmREG->MPDDCSTAT2;
		/*clear the flags which indicate tests ongoing*/
		SL_FLAG_CLEAR(PSCON_SELF_TEST);
		/* Revert to normal operation */
		sl_pmmREG->PRCKEYREG = PMM_PRCKEYREG_MKEY_LOCKSTEP_MODE;
		retVal = TRUE;
	}
	return(retVal);
}
#endif

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_EFuse (SL_SelfTestType testType, boolean bMode, SL_EFuse_Config * config)
{
	uint32 regBkup;
	volatile uint32 regBkupIntEnaSet, regBckupErrInfulence;
	volatile boolean _sl_fault_injection = FALSE;
	boolean retVal = FALSE;
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in range */
	/*LDRA_INSPECTWINDOW 50 */
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	/*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
	if ((_SELFTEST_EFUSE_MIN > testType) || (_SELFTEST_EFUSE_MAX < testType) || !CHECK_RANGE_RAM_PTR(config)){
		SL_Log_Error(FUNC_ID_ST_EFUSE, ERR_TYPE_PARAM, 0U);
		return(FALSE);
	}
#endif
#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
	if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
		SL_Log_Error(FUNC_ID_ST_EFUSE, ERR_TYPE_ENTRY_CON, 2U);
		retVal =  FALSE;
		return(FALSE);
	}
	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_EFUSE, ERR_TYPE_ENTRY_CON, 3U);
		return(FALSE);
	}
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif

	switch(testType) {
	case EFUSE_SELF_TEST_AUTOLOAD:
		/* \todo */
		retVal = FALSE;
		break;

	case EFUSE_SELF_TEST_ECC:
		retVal = TRUE; /* Inputs are fine. Tests are run :) */
		/*flag is set to indicate the current test which is ongoing and
		These flags are used in the sl_esm.c so as to mask the esm callback*/
		SL_FLAG_SET(EFUSE_SELF_TEST_ECC);
		/* Configure the self-test parameters */
		sl_efcREG->SELF_TEST_CYCLES = config->numPatterns;
		sl_efcREG->SELF_TEST_SIGN   = config->seedSignature;
		/* Kick off the self-test */
		sl_efcREG->BOUNDARY = EFC_BOUNDARY_INPUT_EN | EFC_BOUNDARY_SELF_TEST_EN;
		/* If mode is synchronous, update the result now*/
		if((TRUE)==bMode){
		    /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
			while((TRUE) != SL_SelfTest_Status_EFuse(&config->failInfo)){}
		}
		break;

	case EFUSE_SELF_TEST_STUCK_AT_ZERO:
		retVal = TRUE; /* Inputs are fine. Tests are run :) */
		/*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		/*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		status functions to get the pass/failure information*/		
        regBkupIntEnaSet = sl_esmREG->IESR4;
        regBckupErrInfulence = sl_esmREG->IEPSR4;
        sl_esmREG->IECR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_SELTEST_ERR);
      	 sl_esmREG->IEPCR4 = GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_SELTEST_ERR);

		regBkup = (sl_efcREG->BOUNDARY);
		/* Enable the output for errors */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
		sl_efcREG->BOUNDARY = (ST_BOUNDARY_VALUE | EFC_BOUNDARY_OUTPUT_EN);
		/* Check the efuse controller output for the above error outputs */
		if (ST_PIN_VALUE == (ST_PIN_VALUE & sl_efcREG->PINS)) {
			/* If all outputs are set, then test has passed */
			config->failInfo.stResult = ST_PASS;
		} else {
			/* One or more ouputs is/are stuck at zero !! return error */
			config->failInfo.stResult = ST_FAIL;
		}
		/* Clear interrupts & Error Pins only for this event but only if this is the only event */
		if ((uint32) (1u << ESM_G3ERR_EFUSE_AUTOLOAD_ERR) == (uint32) (sl_esmREG->SR1[2] & (1u << ESM_G3ERR_EFUSE_AUTOLOAD_ERR))) {
			_SL_HoldNClear_nError();
		}

		/* Clear any ESM interrupts */
		sl_esmREG->SR4[0] = GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_ERR_OTHER)|GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_SELTEST_ERR);
		sl_esmREG->SR1[2] = GET_ESM_BIT_NUM(ESM_G3ERR_EFUSE_AUTOLOAD_ERR); /* \todo Should clear the ESMKEYR if this event is configured for nERROR */
        /*Restore grp1 esm interrupt enable*/
        sl_esmREG->IESR4 = regBkupIntEnaSet;
        sl_esmREG->IEPSR4 = regBckupErrInfulence;

		/* Restore boundary register */
		sl_efcREG->BOUNDARY = regBkup;
		break;
	default:
		break;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
	SL_Log_Result(FUNC_ID_ST_EFUSE, testType, config->failInfo.stResult , 0U);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
	return(retVal);
}


/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
boolean SL_SelfTest_Status_EFuse (SL_EFuse_FailInfo * failInfoefuse)
{
	boolean retVal = FALSE;

	if ((uint32) (EFC_BOUNDARY_INPUT_EN | EFC_BOUNDARY_SELF_TEST_EN)
			== (uint32) (sl_efcREG->BOUNDARY & (EFC_BOUNDARY_INPUT_EN | EFC_BOUNDARY_SELF_TEST_EN))) {
		/** ECC Self test has been enabled, check the results accordingly */
		if (EFC_PINS_SELF_TEST_DONE == (uint32) (sl_efcREG->PINS & EFC_PINS_SELF_TEST_DONE)) {
			/* self test is complete */
			retVal = TRUE;
			/* Now check the status of the self test */
			if ((EFC_PINS_SELF_TEST_ERROR != (uint32) (sl_efcREG->PINS & EFC_PINS_SELF_TEST_ERROR)))
			{
				/*EFUSE ECC*/
				if(EFC_NO_ERROR == (sl_efcREG->ERROR & EFC_ERROR_CODE)){
					if(0==(sl_esmREG->SR4[0] &
							(GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_ERR_OTHER)|GET_ESM_BIT_NUM(ESM_G1ERR_EFUSE_SELTEST_ERR)))){
						failInfoefuse->stResult = ST_PASS;
					}
				}
			} else {
				/* Self test failed */
				failInfoefuse->stResult = ST_FAIL;
			}
			/* Load the error info anyways */
			failInfoefuse->failInfo= (SL_EFuse_Error)(sl_efcREG->ERROR & EFC_ERROR_CODE);
			/*clear the flags which indicate tests ongoing*/
			SL_FLAG_CLEAR(EFUSE_SELF_TEST_ECC);
		} else {
			/* self test is not complete */
			retVal = FALSE;
		}
	} else {
		/* Since no test was triggered, return FALSE */
		/*SAFETYMCUSW 331 S MR:10.1 <APPROVED> ""*/
		/*SAFETYMCUSW 434 S MR:10.1 <APPROVED> ""*/
		retVal = FALSE;
	}

	return (retVal);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_CCMR4F (SL_SelfTestType testType, boolean bMode, SL_CCMR4F_FailInfo * config)
{
    boolean retVal = FALSE;
    volatile boolean _sl_fault_injection = FALSE;
    volatile uint32 regBkupIntEnaSet, regBckupErrInfulence;
    if(CCMR4F_ERROR_FORCING_TEST_FAULT_INJECT == testType){
		_sl_fault_injection=TRUE;
	}
#ifdef FUNCTION_PARAM_CHECK_ENABLED
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity
      of operation by review"*/
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity
      of operation by review"*/
    if (FALSE == (boolean)CHECK_RANGE_RAM_PTR(config)) {
        SL_Log_Error(FUNC_ID_ST_CCMR4F, ERR_TYPE_PARAM, 0u);
        retVal =  FALSE;
        return retVal;
    }
    if ((_SELFTEST_CCMR4F_MIN > testType) || (_SELFTEST_CCMR4F_MAX < testType)) {
        SL_Log_Error(FUNC_ID_ST_CCMR4F, ERR_TYPE_PARAM, 1u);
        retVal = FALSE;
        return retVal;
    }
#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_CCMR4F, ERR_TYPE_ENTRY_CON, 0u);
        retVal =  FALSE;
        return(FALSE);
    }


	/* If nERROR is active then do not proceed with tests that trigger nERROR */
	if((TRUE) == SL_ESM_nERROR_Active()){
		SL_Log_Error(FUNC_ID_ST_CCMR4F, ERR_TYPE_ENTRY_CON, 2u);
		return(FALSE);
	}
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    if (CCMR4F_CCMKEYR_MODE_LOCKSTEP != (uint32) (ccmr4fREG1->_CCMKEYR & CCMR4F_CCMKEYR_MODE)) {
            retVal =  FALSE;
    }
    else
    {
		switch(testType) {
			case CCMR4F_SELF_TEST:
				/* Set mode to self_test but first ensure that a test is not in process*/
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
				 registers are actually macros" */
				/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
				  registers are actually macros" */
		  		/*flag is set to indicate the current test which is ongoing and
	        	These flags are used in the sl_esm.c so as to mask the esm callback*/
				SL_FLAG_SET(CCMR4F_SELF_TEST);
				ccmr4fREG1->_CCMKEYR = CCMR4F_CCMKEYR_MODE_SELFTEST;
				/* If sync mode loop for the test to complete */
				if ((TRUE) == bMode) {
				    /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
					while (FALSE == SL_SelfTest_Status_CCMR4F(config))
					{

					}
					retVal = TRUE;
				} else {
                /* Since the test is running return TRUE (though this func., call might have not started it) */
                retVal = TRUE;
            }
        break;
        case CCMR4F_ERROR_FORCING_TEST:
        case CCMR4F_ERROR_FORCING_TEST_FAULT_INJECT:
        	retVal = TRUE;
            regBkupIntEnaSet = sl_esmREG->IESR1;
            /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
            regBckupErrInfulence = sl_esmREG->EEPAPR1;
             if(CCMR4F_ERROR_FORCING_TEST ==testType) {
		 		/*flag is set to indicate the current test which is ongoing and
	           	These flags are used in the sl_esm.c so as to mask the esm callback*/
                 SL_FLAG_SET(CCMR4F_ERROR_FORCING_TEST);
                 sl_esmREG->IECR1 = GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST);
               	 sl_esmREG->DEPAPR1 = GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST);
             }
             /* Set the mode to error forcing mode */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
             ccmr4fREG1->_CCMKEYR = CCMR4F_CCMKEYR_MODE_ERRFORCING;
             /* Error is injected & mode is switched back to lockstep (takes 1 cpu cycle).
			 Wait for the mode to switch */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
             /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
             while (CCMR4F_CCMKEYR_MODE_LOCKSTEP != (uint32) (ccmr4fREG1->_CCMKEYR & CCMR4F_CCMKEYR_MODE)) {
             }

             /* Since this raises a G2 ESM Error, it will be cleared by the ESM handler. So check the shadow register */
             /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
               registers are actually macros" */
			  if(((uint32)1u == BF_GET(sl_esmREG->SSR2,BF_CCMR4_CMP_ERROR,BF_CCMR4_CMP_ERROR_LENGTH))) {
				  config->stResult = ST_PASS;
			  } else {
				  config->stResult = ST_FAIL;
			  }

             /* Clear nERROR & Interrupt only if in normal self test mode */
             if(CCMR4F_ERROR_FORCING_TEST == testType) {
                 /* Clear nERROR */
                 _SL_HoldNClear_nError();
                 /* Clear the interrupt */
				 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
				  registers are actually macros" */
                 sl_esmREG->SR1[1] |= GET_ESM_BIT_NUM(ESM_G2ERR_CCMR4_COMP);
                 sl_esmREG->SSR2 |= GET_ESM_BIT_NUM(ESM_G2ERR_CCMR4_COMP);
                 sl_esmREG->SR1[0] |= GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST);
				 /*clear the flags which indicate tests ongoing*/
                 SL_FLAG_CLEAR(CCMR4F_ERROR_FORCING_TEST);
             }
             else
             {
			     /* Nothing to do incase of fault injection */
             }
             sl_esmREG->IESR1 = regBkupIntEnaSet;
             sl_esmREG->EEPAPR1 = regBckupErrInfulence;
             break;

        case CCMR4F_SELF_TEST_ERROR_FORCING:
             retVal = TRUE;
             /*Backup grp1 esm interrupt enable register and clear the interrupt enable */
		     /*the esm interrupts for selftests which generate group 1 interrupts is blocked.Users will have to rely on
		     status functions to get the pass/failure information*/		
             regBkupIntEnaSet = sl_esmREG->IESR1;
             /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
             regBckupErrInfulence = sl_esmREG->EEPAPR1;
             sl_esmREG->IECR1 = GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST);
           	 sl_esmREG->DEPAPR1 = GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST);
			 /*flag is set to indicate the current test which is ongoing and
	         These flags are used in the sl_esm.c so as to mask the esm callback*/
             SL_FLAG_SET(CCMR4F_SELF_TEST_ERROR_FORCING);
             /* Set the mode to self test error forcing mode */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
             ccmr4fREG1->_CCMKEYR = CCMR4F_CCMKEYR_MODE_STERRFORCING;
             /* Error is injected & mode is switched back to lockstep
			 (takes 1 cpu cycle). Wait for the mode to switch */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
             /*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
             while (CCMR4F_CCMKEYR_MODE_LOCKSTEP != (uint32) (ccmr4fREG1->_CCMKEYR & CCMR4F_CCMKEYR_MODE)) {
             }

             /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
               registers are actually macros" */
			 if(GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST) == (sl_esmREG->SR1[0] & GET_ESM_BIT_NUM(ESM_G1ERR_CCMR4_SELFTEST))){
                 config->stResult = ST_PASS;
             }
             else
             {
                 config->stResult = ST_FAIL;
             }
             /* Clear nERROR */
             _SL_HoldNClear_nError();
             /* Clear the interrupt */
			 /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral
			   registers are actually macros" */
             sl_esmREG->SR1[0] = (1u << ESM_G1ERR_CCMR4_SELFTEST);
			 /*clear the flags which indicate tests ongoing*/
             SL_FLAG_CLEAR(CCMR4F_ERROR_FORCING_TEST);
             /*Restore grp1 esm interrupt enable*/
             sl_esmREG->IESR1 = regBkupIntEnaSet;
             sl_esmREG->EEPAPR1 = regBckupErrInfulence;
             break;
        default:
             break;
		}
    }
    /* If the test was fault injection and not self test, then do not mask the call back & clear the *
     *  FAULT_INJECTION flag for subsequent runs*/
    if((TRUE) == _sl_fault_injection){
    		_sl_fault_injection=FALSE;
    }
#if(FUNC_RESULT_LOG_ENABLED == 1)
    SL_Log_Result(FUNC_ID_ST_CCMR4F, testType, (SL_SelfTest_Result)retVal , 0u);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
    return(retVal);
}

/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 91 S MR: 5.2,5.6,5.7 <APPROVED> "Name declared in another C name space is deviated" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_Status_CCMR4F (SL_CCMR4F_FailInfo * failInfoccmr4f)
{
    boolean retVal = FALSE;
#ifdef FUNCTION_PARAM_CHECK_ENABLED
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    if (FALSE == (boolean)CHECK_RANGE_RAM_PTR(failInfoccmr4f)) {
        SL_Log_Error(FUNC_ID_ST_CCMR4F_STATUS, ERR_TYPE_PARAM, 0u);
        retVal =  FALSE;
        return retVal;
    }
#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_CCMR4F_STATUS, ERR_TYPE_ENTRY_CON, 0u);
        retVal =  FALSE;
        return(FALSE);
    }
#endif
    /* Proceed only if in self-test mode else entry condition is wrong */
	/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    if (CCMR4F_CCMKEYR_MODE_SELFTEST != (uint32) (ccmr4fREG1->_CCMKEYR & CCMR4F_CCMKEYR_MODE)) {
            retVal =  FALSE;
    }
    else
    {
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    	/*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
    if (CCMR4F_CCMSR_STC == (uint32) (ccmr4fREG1->_CCMSR & CCMR4F_CCMSR_STC)) {
        /* Restore the CPU mode */
		/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
        ccmr4fREG1->_CCMKEYR = CCMR4F_CCMKEYR_MODE_LOCKSTEP;
		/* \todo document that the Status API must be called after starting the
		self-test to restore the cpu mode */
        retVal = TRUE; /* Indicate that the self test was complete */
		/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
        /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
        if (CCMR4F_CCMSR_STE == (uint32) (ccmr4fREG1->_CCMSR & CCMR4F_CCMSR_STE)) {
            /* self-test failed */
            failInfoccmr4f->stResult = ST_FAIL;
            /* retrieve the err info */
			/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
            /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
            if (CCMR4F_CCMSR_STET == (uint32) (ccmr4fREG1->_CCMSR & CCMR4F_CCMSR_STET)) {
                /* \todo Looks like there is a type in TRM w.r.t bit description. */
                failInfoccmr4f->failInfo = CCMR4F_ST_ERR_COMPARE_MATCH;
            } else {
                failInfoccmr4f->failInfo = CCMR4F_ST_ERR_COMPARE_MISMATCH;
            }
        } else {
            failInfoccmr4f->stResult = ST_PASS;
        }
		/*clear the flags which indicate tests ongoing*/
	    SL_FLAG_CLEAR(CCMR4F_SELF_TEST);
    } else {
        retVal = FALSE; /* Indicate that the self test was not complete */
    }
#if(FUNC_RESULT_LOG_ENABLED == 1)
    SL_Log_Result(FUNC_ID_ST_CCMR4F_STATUS, (SL_SelfTestType)0u, failInfoccmr4f->stResult, 0u);
#endif
    }
    return(retVal);
}

/** @fn void adcCalibration(sl_adcBASE_t *adc)
*   @brief Computes offset error using Calibration mode
*   @param[in] adc Pointer to ADC module:
*              - sl_adcREG1: ADC1 module pointer
*              - sl_adcREG2: ADC2 module pointer
*   This function computes offset error using Calibration mode
*
*/
void SL_adcCalibration(sl_adcBASE_t *adc)
{

	uint32 conv_val[5U]={0U,0U,0U,0U,0U};
	uint32 loop_index=0U;
	uint32 offset_error=0U;
	uint32 backup_mode;

#ifdef FUNCTION_PARAM_CHECK_ENABLED

    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    if (FALSE == (boolean)CHECK_RANGE_RAM_PTR(adc)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 1u);
        return;
    }
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    if((adc != sl_adcREG1) && (adc != sl_adcREG2) && (adc != NULL)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 2u);
        return;
    }

#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 0u);
        return;
    }
    /*todo check if these checks are redundant*/
    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
    if ((uint32)1u == adc->RSTCR) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 1u);
        return;
    }
    if(0u != (adc->OPMODECR & ADC_POWERDOWN_MODE)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 2u);
        return;
    }
    if(0u == (adc->OPMODECR & ADC_ENABLE)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 3u);
        return;
    }
#endif

	/** - Backup Mode before Calibration  */
	backup_mode = adc->OPMODECR;

	/** - Enable 12-BIT ADC  */
	sl_adcREG1->OPMODECR |= 0x80000000U;

	/* Disable all channels for conversion */
	adc->GxSEL[0]=0x00U;
	adc->GxSEL[1]=0x00U;
	adc->GxSEL[2]=0x00U;

	for(loop_index=0U;loop_index<4U;loop_index++)
	{
		/* Disable Self Test and Calibration mode */
		adc->CALCR=0x0U;

		switch(loop_index)
		{
			case 0U : 	/* Test 1 : Bride En = 0 , HiLo =0 */
						adc->CALCR=0x0U;
						break;

			case 1U :	/* Test 1 : Bride En = 0 , HiLo =1 */
						adc->CALCR=0x0100U;
						break;

			case 2U : 	/* Test 1 : Bride En = 1 , HiLo =0 */
						adc->CALCR=0x0200U;
						break;

			case 3U : 	/* Test 1 : Bride En = 1 , HiLo =1 */
						adc->CALCR=0x0300U;
						break;
			default :
			            break;
		}

		/* Enable Calibration mode */
		adc->CALCR|=0x1U;

		/* Start calibration conversion */
		adc->CALCR|=0x00010000U;

		/* Wait for calibration conversion to complete */
		/*SAFETYMCUSW 28 D <APPROVED> "Reason - Design change necessary to remove the infinite while loop" */
		while((adc->CALCR & 0x00010000U)==0x00010000U)
	    {
	    } /* Wait */

		/* Read converted value */
		conv_val[loop_index]= adc->CALR;
	}

	/* Disable Self Test and Calibration mode */
	adc->CALCR=0x0U;

	/* Compute the Offset error correction value */
	conv_val[4]=conv_val[0]+ conv_val[1] + conv_val[2] + conv_val[3];

	conv_val[4]=(conv_val[4]/4);

	offset_error=conv_val[4]-0x7FFU;

	/*Write the offset error to the Calibration register */
	/* Load 2's complement of the computed value to ADCALR register */
	offset_error=~offset_error;
	offset_error=offset_error & 0xFFFU;
	offset_error=offset_error+1U;

	adc->CALR = offset_error;

  /** - Restore Mode after Calibration  */
	adc->OPMODECR = backup_mode;

    return;

 /**   @note The function adcInit has to be called before using this function. */

}

/*SAFETYMCUSW 62 D MR: 16.7 <APPROVED> "changes may be made in the usage of the config" */
/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTest_ADC(SL_SelfTestType testType, boolean mode, SL_ADC_Config * config, SL_ADC_Pinstatus  * pinstatus)
{
    uint16 adRefHi = 0u;
    uint16 adRefLo = 0u;
    uint16 approximated_value;
    SL_ADC_Data Vd, Vu, Vn;
    SL_SelfTest_Result  adc_stResult = ST_PASS;

	boolean retVal =  FALSE;


    uint32 ModeCtrlRegWorkingCopy, IntEnaRegWorkingCopy, IntThrRegWorkingCopy;

#ifdef FUNCTION_PARAM_CHECK_ENABLED
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    if (FALSE == (boolean)CHECK_RANGE_RAM_PTR(pinstatus)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 0u);
		retVal =  FALSE;
        return retVal;
    }
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    /*SAFETYMCUSW 439 S MR:11.3 <APPROVED> "Reason -  This is an advisory by MISRA.Verified validity of operation by review"*/
    if (FALSE == (boolean)CHECK_RANGE_RAM_PTR(config)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 1u);
        retVal =  FALSE;
        return retVal;
    }
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
	/*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    if((config->adcbase != sl_adcREG1) && (config->adcbase != sl_adcREG2) && (config->adcbase != NULL)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 2u);
	    retVal =  FALSE;
        return retVal;
    }
#if defined(_TMS570LS31x_) || defined(_TMS570LS12x_) || defined(_RM48x_) || defined(_RM46x_)
/*ADC Channels 0 to 23 are available in TMS570LS31x, TMS570LS12x, RM48 and RM46x devices*/
    if((config->adc_channel >= 24u)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 3u);
	    retVal =  FALSE;
        return retVal;
    }
#endif
#if defined(_RM42x_) || defined(_TMS570LS04x_)
/*These ADC channels are not available in TMS570LS04x and RM42x devices*/
    if(((config->adc_channel > 11u) && (config->adc_channel < 16u)) ||
   		((config->adc_channel > 17u) && (config->adc_channel < 20u)) ||
   		(config->adc_channel > 21u)){
		SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_PARAM, 3u);
		retVal = FALSE;
		return retVal;
	}
#endif

#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 0u);
        retVal =  FALSE;
        return retVal;
    }
    /*todo check if these checks are redundant*/
    /*SAFETYMCUSW 134 S MR: 12.2 <APPROVED> "Reason -  FALSE_POSITIVE The rule requires that the expression should be
guaranteed to have the same value regardless of the order in which the operands within the expression are evaluated.
This usually means no more than one volatile access occuring in the expression.The recommendation that simple
assignments should be used is intended to be restricted to simple assignments of the form x = v and not
"simple assignments" according to the ISO definition. However, the recommendation does not have to be followed
in order to be compliant with the rule. You should implement the rule (the value should be independent of the
evaluation order) for compliance purposes and you might choose to issue a warning for non-simple assignments
or you might choose to ignore them." */
    if ((uint32)1u == config->adcbase->RSTCR) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 1u);
		retVal =  FALSE;
        return retVal;
    }
    if(0u != (config->adcbase->OPMODECR & ADC_POWERDOWN_MODE)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 2u);
		retVal =  FALSE;
        return retVal;
    }
    if(0u == (config->adcbase->OPMODECR & ADC_ENABLE)) {
        SL_Log_Error(FUNC_ID_ST_ADC, ERR_TYPE_ENTRY_CON, 3u);
		retVal =  FALSE;
        return retVal;
    }
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
    sl_adcBASE_t *adc = config->adcbase;
    uint8 channel = config->adc_channel;
    /*initializing the Vd,Vu,Vn values to 0 on start*/
    Vd.value = 0u;
    Vu.value = 0u;
    Vn.value = 0u;

    /*setting pinstatus to default value*/
	*pinstatus = ADC_PIN_UNDETERMINED;
	/*backup copy of the interrupt and mode control registers of adc*/
    IntEnaRegWorkingCopy = adc->GxINTENA[sl_adcGROUP1];
    IntThrRegWorkingCopy = adc->GxINTCR[sl_adcGROUP1];
    ModeCtrlRegWorkingCopy = adc->OPMODECR;

    /*Disable Interrupts*/
    adc->GxINTENA[sl_adcGROUP1] = 0u;

    /*disable any self tst and Calib mode first */
    adc->CALCR = 0u;

    /*first find out AdRefHi and AdRefLo by using Calibration method*/
    /** - Backup Mode before Calibration  */

    /** - Enable 12-BIT ADC  */
    (adc->OPMODECR) |= ADC_12BIT_RESOLUTION;
    /* Disable all channels for conversion */
    /*Event select*/
    adc->GxSEL[sl_adcGROUP1] = 0u;

	/* Test 1 : Bride En = 1 , HiLo =0 Calib Enabled, Start Calibration */
    /*SAFETYMCUSW 28 D MR: 16.7 <APPROVED> "Overall design change needed" */
    adc->CALCR = (ADC_CALIB_BRIDGE_ENABLE | ADC_START_CALIBRARION | ADC_ENABLE_CALIBRATION);

	/* Wait for calibration conversion to complete */
	while ((adc->CALCR & ADC_START_CALIBRARION) == ADC_START_CALIBRARION) {

	}
	/* Read converted value */
	adRefLo = (uint16)adc->CALR;

	/*  Bride En = 1 , HiLo =1 Calib Enabled, Start Calibration */
	adc->CALCR = (ADC_CALIB_BRIDGE_ENABLE | ADC_CALIB_HILO_ENABLE | ADC_START_CALIBRARION | ADC_ENABLE_CALIBRATION);
	/* Wait for calibration conversion to complete */
    /*SAFETYMCUSW 28 D MR: 16.7 <APPROVED> "Overall design change needed" */
    while ((adc->CALCR & ADC_START_CALIBRARION) == ADC_START_CALIBRARION) {
    }
	/* Read converted value */
	adRefHi = (uint16)adc->CALR;

	/** - Restore Mode after Calibration  */
	adc->OPMODECR = ModeCtrlRegWorkingCopy;
	/* disable any self tst and Calib mode first*/
    adc->CALCR = 0u;

    /*Calibrate the ADC so as to fill appropriate value in CALR register*/
    /*SAFETYMCUSW 440 S MR: 11.3 <APPROVED> "The base address of the peripheral registers are actually macros" */
    SL_adcCalibration(adc);

    /*Calculate Vn*/
    /*enable ADC channel which needs to be tested */
    _SL_SelfTest_adcStartConversion_selChn(adc, channel, ADC_FIFO_SIZE, (uint32) sl_adcGROUP1);
    /* check for the status of the group to see if it is finished*/
    /*SAFETYMCUSW 28 D MR: 16.7 <APPROVED> "Overall design change needed" */
    while (FALSE == _SL_SelfTest_adcIsConversionComplete(adc, (uint32) sl_adcGROUP1)) {

    }
    /* copy the results into the Vn*/
    _SL_SelfTest_adcGetSingleData(adc, (uint32) sl_adcGROUP1, &Vn);

    /* for this self test put the adc group in single shot non streaming mode & later restore the setting to original */
    /* set the ADC hw in the self test mode and start the test.*/
    /*Calculate Vd*/
    adc->CALCR |= ADC_ENABLE_SELFTEST;
    /* set HiLo to 0 to connect AdVref = low */
    adc->CALCR = (adc->CALCR)&(~ADC_CALIB_HILO_ENABLE);
    /*enable ADC channel which needs to be tested */
    _SL_SelfTest_adcStartConversion_selChn(adc, channel, ADC_FIFO_SIZE, (uint32) sl_adcGROUP1);
    /* check for the status of the group to see if it is finished*/
    /*SAFETYMCUSW 28 D MR: 16.7 <APPROVED> "Overall design change needed" */
    while (FALSE == _SL_SelfTest_adcIsConversionComplete(adc, (uint32) sl_adcGROUP1)) {

    }
    /* copy the results into the Vd*/
    _SL_SelfTest_adcGetSingleData(adc, (uint32) sl_adcGROUP1, &Vd);

    /*Calculate Vu*/
    adc->CALCR |= ADC_CALIB_HILO_ENABLE;
    /*enable ADC channel which needs to be tested */
    _SL_SelfTest_adcStartConversion_selChn(adc, channel, ADC_FIFO_SIZE, (uint32) sl_adcGROUP1);
    /* check for the status of the group to see if it is finished*/
    /*SAFETYMCUSW 28 D MR: 16.7 <APPROVED> "Overall design change needed" */
    while (FALSE == _SL_SelfTest_adcIsConversionComplete(adc, (uint32) sl_adcGROUP1)) {

    }
    /* copy the results into the Vn*/
    _SL_SelfTest_adcGetSingleData(adc, (uint32) sl_adcGROUP1, &Vu);

    /*Approximation of the values is done here*/
    /* find the differences and set the voltages levels to ref_low or rel_hig for proper comparision */
    approximated_value = _SL_Approximate_value(Vn.value,adRefHi,(uint8)ADC_APPROXIMATION_THRESHOLD);
    if(approximated_value == Vn.value)
    {
        Vn.value = _SL_Approximate_value(Vn.value,adRefLo,(uint8)ADC_APPROXIMATION_THRESHOLD);
    }
    else
    {
        Vn.value = approximated_value;
    }
    approximated_value = _SL_Approximate_value(Vu.value,adRefHi,(uint8)ADC_APPROXIMATION_THRESHOLD);
    if(approximated_value == Vu.value)
    {
	    /*SAFETYMCUSW 91 D MR: 16.10 <APPROVED> "False negative" */
        Vu.value = _SL_Approximate_value(Vu.value,adRefLo,(uint8)ADC_APPROXIMATION_THRESHOLD);
    }
    else
    {
        Vu.value = approximated_value;
    }
    approximated_value = _SL_Approximate_value(Vd.value,adRefHi,(uint8)ADC_APPROXIMATION_THRESHOLD);
    /*SAFETYMCUSW 91 D MR: 16.10 <APPROVED> "False negative" */
    if(approximated_value == Vd.value)
    {
        Vd.value = _SL_Approximate_value(Vd.value,adRefLo,(uint8)ADC_APPROXIMATION_THRESHOLD);
    }
    else
    {
        Vd.value = approximated_value;
    }

    if ((Vn.value == adRefHi) && (Vu.value == adRefHi) && (Vd.value == adRefHi)) {
        *pinstatus = ADC_PIN_SHORTED_TO_ADVREF_HIGH;
    } else if ((Vn.value == adRefLo) && (Vu.value == adRefLo) && (Vd.value == adRefLo)) {
        *pinstatus = ADC_PIN_SHORTED_TO_ADVREF_LOW;
    } else if (((Vu.value < adRefHi) && (Vu.value > Vn.value)) && ((Vd.value > adRefLo) && (Vd.value < Vn.value))) {
        *pinstatus = ADC_PIN_GOOD;
    } else if ((Vu.value == adRefHi) && (Vd.value == adRefLo)) {
        *pinstatus = ADC_PIN_OPEN;
    } else {
        *pinstatus = ADC_PIN_UNDETERMINED;
    }

    /*disable any self tst and Calib mode first*/
    adc->CALCR = 0u;
    /* Disable all channels for conversion */
    /* Disable all channels for conversion */
    /*Event select*/
    adc->GxSEL[(uint32) sl_adcGROUP1] = 0u;
    /*Enable Interrupts if it was enabled before the selftest*/
    adc->GxINTENA[(uint32) sl_adcGROUP1] = IntEnaRegWorkingCopy;
    adc->GxINTCR[(uint32) sl_adcGROUP1] = IntThrRegWorkingCopy;

#if(FUNC_RESULT_LOG_ENABLED == 1)
    SL_Log_Result(FUNC_ID_ST_ADC, testType, adc_stResult , 0u);
#endif

    retVal =  TRUE;
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
    return retVal;
}


/*reserved location in memory map*/
#define SCR_RESERVED_LOCATION 0x70000000U
/*reserved location in memory map*/
#define PCR_RESERVED_LOCATION 0xFD000000U
/*SAFETYMCUSW 61 D MR: 8.10,8.11 <APPROVED> "This function will be called by application so not static" */
/*SAFETYMCUSW 7 C MR: 14.7 <APPROVED> "Reviewed - The entry condition and parameter checks shall exit immediately" */
boolean SL_SelfTestL2L3Interconnect(SL_SelfTestType testType)
{
    boolean retVal = FALSE;
    uint32 read_reserved_word;
#ifdef FUNCTION_PARAM_CHECK_ENABLED
	/* Verify that the parameters are in rage */
	if ((_SELFTEST_L2L3INTERCONNECT_MIN > testType) || (_SELFTEST_L2L3INTERCONNECT_MAX < testType)) {
		SL_Log_Error(FUNC_ID_ST_L2L3INTERCONNECT, ERR_TYPE_PARAM, 0u);
		retVal =  FALSE;
		return(retVal);
	}
#endif

#ifdef FUNCTION_ENTRY_CONDITION_CHECK_ENABLED
    /*check for priveleged mode*/
    if (ARM_MODE_USR == _SL_Get_ARM_Mode()) {
        SL_Log_Error(FUNC_ID_ST_L2L3INTERCONNECT, ERR_TYPE_ENTRY_CON, 0u);
        retVal =  FALSE;
        return(retVal);
    }
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Start_Profiling(testType);
#endif
	switch(testType)
	{
	/*Access a reserve location in the EMIF register space,as EMIF lies on SCR*/
		case L2INTERCONNECT_FAULT_INJECT:
			/*try to read reserved word in the emif register map*/
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
			_SL_Barrier_Data_Access();
			read_reserved_word = *((uint32*)SCR_RESERVED_LOCATION);
			retVal = TRUE;
			break;
	/*Access a reserve location in the DCAN register space,as DCAN lies on PCR*/
		case L3INTERCONNECT_FAULT_INJECT:
			/*try to read reserved word in the pbist register map*/
#if FUNCTION_PROFILING_ENABLED
		SL_Record_Errorcreationtick(testType);
#endif
			_SL_Barrier_Data_Access();
			read_reserved_word = *((uint32*)PCR_RESERVED_LOCATION);
			retVal = TRUE;
			break;

		default:
			retVal = FALSE;
			break;
	}
#if(FUNC_RESULT_LOG_ENABLED == 1)
    SL_Log_Result(FUNC_ID_ST_L2L3INTERCONNECT, testType, (SL_SelfTest_Result)retVal , 0u);
#endif
#if FUNCTION_PROFILING_ENABLED
	SL_Stop_Profiling(testType);
#endif
    return(retVal);
}

